@@ -2,7 +2,7 @@
 // the GNU General Public License (See COPYING for details).
 // Copyright (C) 2001 - 2002 Simon Goodall
 
-// $Id: Log.cpp,v 1.7 2004/04/27 15:07:01 simon Exp $
+// $Id: Log.cpp,v 1.9 2005/04/13 12:16:03 simon Exp $
 
 #include "Log.h"
 #include <iostream>
@@ -13,10 +13,6 @@
  * only included in debug mode
  */ 
 
-#ifdef HAVE_CONFIG_H
-  #include "config.h"
-#endif
-
 #ifdef USE_MMGR
   #include "common/mmgr.h"
 #endif
@@ -38,7 +34,7 @@ void Log::writeLog(const std::string &msg, LogLevel level) {
     case LOG_ERIS: type = "Eris"; break;		
     case LOG_INFO: type = "Info"; break;
   }
-  std::cout << "TIMESTAMP - " << type << ": " << msg << std::endl << std::flush;
+  std::cout << type << ": " << msg << std::endl << std::flush;
 }
 
 } /* namespace Sear */
