@@ -1,12 +1,8 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2004 Simon Goodall, University of Southampton
+// Copyright (C) 2001 - 2005 Simon Goodall, University of Southampton
 
-// $Id: Utility.cpp,v 1.8 2004/06/11 00:53:13 alriddoch Exp $
-
-#ifdef HAVE_CONFIG_H
-  #include "config.h"
-#endif
+// $Id: Utility.cpp,v 1.12 2005/08/18 10:56:36 simon Exp $
 
 #include "Utility.h"
 
@@ -26,9 +22,10 @@
 #else
   static const bool debug = false;
 #endif
-namespace Sear {
 
-const std::string Tokeniser::delimeters = " ";
+#include "common/types.h"
+
+namespace Sear {
 
 void ReduceToUnit(float vector[3]) {
   float length;
@@ -88,25 +85,25 @@ void QuatToMatrix(const WFMath::Quaternion & quat, float m[4][4]) {
   wy = quat.scalar() * y2;
   wz = quat.scalar() * z2;
 
-  m[0][0] = 1.0 - (yy + zz);
+  m[0][0] = 1.0f - (yy + zz);
   m[0][1] = xy - wz;
   m[0][2] = xz + wy;
-  m[0][3] = 0.0;
+  m[0][3] = 0.0f;
              
   m[1][0] = xy + wz;
-  m[1][1] = 1.0 - (xx + zz);
+  m[1][1] = 1.0f - (xx + zz);
   m[1][2] = yz - wx;
-  m[1][3] = 0.0;
+  m[1][3] = 0.0f;
   
   m[2][0] = xz - wy;
   m[2][1] = yz + wx;  
-  m[2][2] = 1.0 - (xx + yy);
-  m[2][3] = 0.0;
+  m[2][2] = 1.0f - (xx + yy);
+  m[2][3] = 0.0f;
     
-  m[3][0] = 0;
-  m[3][1] = 0;
-  m[3][2] = 0;
-  m[3][3] = 1;  
+  m[3][0] = 0.0f;
+  m[3][1] = 0.0f;
+  m[3][2] = 0.0f;
+  m[3][3] = 1.0f;  
 }
 
 WFMath::AxisBox<3> bboxCheck(WFMath::AxisBox<3> bbox) {
@@ -125,25 +122,47 @@ WFMath::AxisBox<3> bboxCheck(WFMath::AxisBox<3> bbox) {
  else return WFMath::AxisBox<3>(bbox.highCorner(), bbox.lowCorner());	  
 }
 
-void Tokeniser::initTokens(const std::string &tokens) {
-  token_string = tokens;
-  last_pos = token_string.find_first_not_of(delimeters, 0);
-  pos = token_string.find_first_of(delimeters, last_pos);
+void Tokeniser::initTokens(const std::string &String) {
+  m_String = String;
+  m_Begin = 0;
+  m_End = 0;
 }
 
 std::string Tokeniser::nextToken() {
-  if (last_pos == std::string::npos) return "";
-  std::string token = token_string.substr(last_pos, pos - last_pos);
-  last_pos = token_string.find_first_not_of(delimeters, pos);
-  pos = token_string.find_first_of(delimeters, last_pos);
-  return token;
+  std::string sReturn = "";
+  bool bInString = false;
+  bool bIsEscaped = false;
+  
+  for(m_Begin = m_End; (m_Begin < m_String.length()) && (m_String[m_Begin] == ' '); ++m_Begin);
+  if(m_Begin == m_String.length()) {
+    m_End = m_Begin;
+    
+    return "";
+  }
+  for(m_End = m_Begin; m_End < m_String.length(); ++m_End) {
+    if((m_String[m_End] == '\\') && (bIsEscaped == false)) {
+      bIsEscaped = true;
+    } else {
+      if((m_String[m_End] == ' ') && (bInString == false) && (bIsEscaped == false)) {
+        break;
+      } else if((m_String[m_End] == '"') && (bIsEscaped == false)) {
+        bInString = (bInString == false);
+      } else {
+        sReturn += m_String[m_End];
+      }
+      bIsEscaped = false;
+    }
+  }
+  
+  return sReturn;
 }
 
 std::string Tokeniser::remainingTokens() {
-  if (last_pos == std::string::npos) return "";
-  return token_string.substr(last_pos, token_string.size() - last_pos);
-}                                
-  
+  for(m_Begin = m_End; (m_Begin < m_String.length()) && (m_String[m_Begin] == ' '); ++m_Begin);
+    
+  return m_String.substr(m_Begin);
+}
+
 unsigned char *xpm_to_image(const char *image[], unsigned int &width, unsigned int &height) {
   unsigned int i, row, col;
   unsigned int num_colours = 0;
@@ -178,4 +197,34 @@ unsigned char *xpm_to_image(const char *image[], unsigned int &width, unsigned i
   return data;  
 }
 
+OrientBBox::OrientBBox()
+{
+    for (unsigned int P=0; P < LAST_POSITION; ++P) {
+      points[P] = WFMath::Vector<3>(0,0,0);
+    }
+}
+
+OrientBBox::OrientBBox(const WFMath::AxisBox<3>& ab)
+{
+  WFMath::Point<3> high = ab.highCorner();
+  WFMath::Point<3> low = ab.lowCorner();
+
+  points[UPPER_LEFT_FRONT]  = WFMath::Vector<3>(high.x(), high.y(), high.z());
+  points[UPPER_RIGHT_FRONT] = WFMath::Vector<3>(low.x(), high.y(), high.z());
+  points[UPPER_LEFT_BACK]   = WFMath::Vector<3>(high.x(), low.y(), high.z());
+  points[UPPER_RIGHT_BACK]  = WFMath::Vector<3>(low.x(), low.y(), high.z());
+
+  points[LOWER_LEFT_FRONT]  = WFMath::Vector<3>(high.x(), high.y(), low.z());
+  points[LOWER_RIGHT_FRONT] = WFMath::Vector<3>(low.x(), high.y(), low.z());
+  points[LOWER_LEFT_BACK]   = WFMath::Vector<3>(high.x(), low.y(), low.z());
+  points[LOWER_RIGHT_BACK]  = WFMath::Vector<3>(low.x(), low.y(), low.z());
+}
+
+void OrientBBox::rotate(const WFMath::Quaternion& q)
+{
+  for (unsigned int P=0; P < LAST_POSITION; ++P) {
+    points[P] = points[P].rotate(q);
+  }
+}
+
 } /* namespace Sear */
