@@ -2,12 +2,14 @@
 // the GNU General Public License (See COPYING for details).
 // Copyright (C) 2001 - 2004 Simon Goodall
 
-// $Id: types.h,v 1.6 2004/06/20 18:43:35 simon Exp $
+// $Id: types.h,v 1.8 2005/05/06 17:26:00 jmt Exp $
 
 #ifndef SEAR_COMMON_TYPES_H
 #define SEAR_COMMON_TYPES_H 1
 
 #include <wfmath/vector.h>
+#include <wfmath/quaternion.h>
+#include <wfmath/axisbox.h>
 
 namespace Sear {
 
@@ -62,23 +64,17 @@ typedef struct {
   float emission[4];
 } Material;
 
-typedef struct {
-  Vertex_3 *vertex_array;
-  unsigned int vertex_vbo;
-  Normal *normal_array;
-  unsigned int normal_vbo;
-  Texel *tex_coord_array;
-  unsigned int tex_vbo;
-  unsigned int number_of_points;
-  DataType data_type;
-  Material material;
-  TextureObject texture_1;
-  unsigned int disp_list;
-} Mesh;
-
-typedef struct {
-  WFMath::Vector<3> points[8];
-} OrientBBox;
+class OrientBBox
+{
+public:
+    OrientBBox(const WFMath::AxisBox<3>& axisBox);
+    
+    OrientBBox();
+    
+    void rotate(const WFMath::Quaternion& q);
+    
+    WFMath::Vector<3> points[8];
+};
 
 typedef enum {
   UPPER_LEFT_FRONT = 0,
