@@ -1,9 +1,13 @@
+// This file may be redistributed and modified only under the terms of
+// the GNU General Public License (See COPYING for details).
+// Copyright (C) 2001 - 2006 Simon Goodall, University of Southampton
 
 #ifndef SEAR_SKYDOME_H
 #define SEAR_SKYDOME_H 1
 
 #include <sage/sage.h>
-//#include <sage/GL.h>
+#include <sage/GL.h>
+
 #include <math.h>
 #include <iostream>
 #include "renderers/RenderSystem.h"
@@ -18,7 +22,8 @@ public:
   virtual ~SkyDome();
   
   void render();
-  void invalidate() {}
+  void contextCreated();
+  void contextDestroyed(bool check);
     
 private:
     float* genVerts(float radius, int levels, int segments);
@@ -34,7 +39,7 @@ private:
   float *m_verts, *m_texCoords;
   int m_size;
   
-  unsigned int m_vb_verts, m_vb_texCoords;
+  GLuint m_vb_verts, m_vb_texCoords;
   static float m_box[];
   static float m_quad_v[];
   static float m_quad_t[];
@@ -42,6 +47,10 @@ private:
   TextureID m_textures[5];
   
   std::vector<Color_4> m_horizonColors;
+
+  float m_radius;
+  int m_levels;
+  int m_segments;
 };
 
 } // namespace Sear
