@@ -1,14 +1,20 @@
-#ifdef HAVE_CONFIG_H
-    #include "config.h"
-#endif
+// This file may be redistributed and modified only under the terms of
+// the GNU General Public License (See COPYING for details).
+// Copyright (C) 2004 - 2006 Simon Goodall
 
-#include "Stars.h"
+// $Id: Stars.cpp,v 1.6 2006/02/05 21:09:50 simon Exp $
 
 
 #include <sage/GL.h>
 #include <wfmath/vector.h>
 #include <wfmath/MersenneTwister.h>
 
+#include "Stars.h"
+
+#ifdef USE_MMGR
+  #include "common/mmgr.h"
+#endif
+
 namespace Sear {
 
 Stars::Stars()
@@ -47,7 +53,6 @@ void Stars::render()
 
     
     glEnableClientState(GL_COLOR_ARRAY);
-    glEnableClientState(GL_VERTEX_ARRAY);
     
     glColorPointer(4, GL_UNSIGNED_BYTE, 0, m_colors);
     glVertexPointer(3, GL_FLOAT, 0, m_locations);
@@ -55,7 +60,6 @@ void Stars::render()
     glDrawArrays(GL_POINTS, 0, 1000);
 
     glDisableClientState(GL_COLOR_ARRAY);
-    glDisableClientState(GL_VERTEX_ARRAY);
     
     glDepthMask(GL_TRUE);
  
