@@ -7,22 +7,32 @@
 
 #include "gui/Container.h"
 
+#include <list>
+
 namespace Sear {
 
 /// Abstract class for widget containing a series of other widgets
 /// If this starts to seem a little gtk+, then that's because I stole
 /// the idea from gtk+
 class Box : public Container {
-protected:
-  Box();
-
 private:
   // Private and unimplemented to prevent slicing
   Box(const Box &);
   const Box & operator=(const Box &);
+protected:
+  Box(int packing = 2, int padding = 0);
+
+  std::list<Widget *> m_boxContents;
+  unsigned int m_packing;
+  unsigned int m_padding;
 public:
   virtual ~Box();
 
+  size_t size() const {
+    return m_boxContents.size();
+  }
+
+  Widget * push_back(Widget *);
   void render();
 };
 
@@ -32,8 +42,10 @@ private:
   VBox(const VBox &);
   const VBox & operator=(const VBox &);
 public:
-  VBox();
+  VBox(int packing = 2, int padding = 0);
   virtual ~VBox();
+
+  virtual void map(Window * win, int x, int y, int & w, int & h);
 };
 
 class HBox : public Box {
@@ -42,8 +54,10 @@ private:
   HBox(const HBox &);
   const HBox & operator=(const HBox &);
 public:
-  HBox();
+  HBox(int packing = 2, int padding = 0);
   virtual ~HBox();
+
+  virtual void map(Window * win, int x, int y, int & w, int & h);
 };
 
 } // namespace Sear
