@@ -1,8 +1,8 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2002 Simon Goodall
+// Copyright (C) 2001 - 2006 Simon Goodall
 
-// $Id: 3ds.h,v 1.13 2004/06/23 17:24:49 simon Exp $
+// $Id: 3ds.h,v 1.20 2006/01/28 15:35:48 simon Exp $
 
 #ifndef SEAR_3DS_H
 #define SEAR_3DS_H 1
@@ -13,16 +13,22 @@
 #include <map>
 
 #include <lib3ds/file.h>
+#include <lib3ds/node.h>
+
+#include <sigc++/object_slot.h>
+
+#include <varconf/Config.h>
 
 #include "common/types.h"
 
-#include "src/Model.h"
+#include "Model.h"
 
 namespace Sear {
 
 // Forward declarations	
+class RenderObject;
 
-class ThreeDS : public Model {
+class ThreeDS : public Model, public SigC::Object {
 public:
   /*
    * Defualt constructor
@@ -37,37 +43,20 @@ public:
   /*
    * Initialise 3ds model. Should probably be combined with loadModel
    */ 
-  bool init(const std::string &file_name);
+  int init(const std::string &file_name);
 
   /*
    * Called when model is to be removed from memory. It cleans up its children.
    */
-  void shutdown();
+  int shutdown();
   void render(bool);
 
-  void invalidate();
+  void contextCreated();
+  void contextDestroyed(bool check);
   void setHeight(float height) { m_height = height; }
 
 protected:
-  class RenderObject {
-public:
-   RenderObject() : 
-     vertex_data(NULL),
-     normal_data(NULL),
-     texture_data(NULL),
-     num_points(0),
-     texture_id(0),
-     texture_mask_id(0)
- {}
-    Vertex_3 *vertex_data;
-    Normal *normal_data;
-    Texel *texture_data;
-    unsigned int num_points;
-    int texture_id;
-    int texture_mask_id;
-    std::string material_name;
-  } ;
-
+  
   typedef struct {
     float ambient[4];
     float diffuse[4];
@@ -75,16 +64,22 @@ public:
     float shininess;
   } Material;
   
-  void render_node(Lib3dsNode * node, Lib3dsFile * file);
-  void render_mesh(Lib3dsMesh * mesh, Lib3dsFile * file);
-  void render_file(Lib3dsFile * file);
+  void render_node(Lib3dsNode *node, Lib3dsFile *file);
+  void render_file(Lib3dsFile *file);
+  void render_mesh(Lib3dsMesh *mesh, Lib3dsFile *file, Lib3dsObjectData *d);
   
-  std::list<RenderObject*> render_objects;
-  std::map<std::string, Material*> material_map;
-  bool _initialised;
-  unsigned int _list;
-  unsigned int _list_select;
+//  void varconf_callback(const std::string &section, const std::string &key, varconf::Config &config);
+  void varconf_error_callback(const char *message);
+
+
+  std::list<RenderObject*> m_render_objects;
+  typedef std::map<std::string, Material*> MaterialMap;
+  MaterialMap m_material_map;
+  bool m_initialised;
+  unsigned int m_list;
+  unsigned int m_list_select;
   float m_height;
+  varconf::Config m_config;  
 };
 
 } /* namespace Sear */
