@@ -1,13 +1,13 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2002 Simon Goodall
+// Copyright (C) 2001 - 2005 Simon Goodall
 
-// $Id: 3ds_Loader.h,v 1.6 2002/11/12 23:59:22 simon Exp $
+// $Id: 3ds_Loader.h,v 1.8 2005/03/15 17:55:03 simon Exp $
 
 #ifndef SEAR_3DS_LOADER_H
 #define SEAR_3DS_LOADER_H 1
 
-#include "src/ModelLoader.h"
+#include "ModelLoader.h"
 
 namespace Sear {
 
@@ -18,7 +18,7 @@ class ModelHandler;
 class ThreeDS_Loader : public ModelLoader {
 public:	
   ThreeDS_Loader(ModelHandler *mh);
-  ~ThreeDS_Loader();
+  ~ThreeDS_Loader() {}
 
   ModelRecord *loadModel(Render *render, ObjectRecord *record, const std::string &model_id, varconf::Config &model_config);
 	  
