@@ -1,8 +1,8 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2002 Simon Goodall, University of Southampton
+// Copyright (C) 2001 - 2006 Simon Goodall, University of Southampton
 
-// $Id: BoundBox.h,v 1.9 2004/04/26 15:45:20 simon Exp $
+// $Id: BoundBox.h,v 1.13 2006/01/28 15:35:48 simon Exp $
 
 #ifndef SEAR_BOUNDBOX_H
 #define SEAR_BOUNDBOX_H 1
@@ -14,10 +14,12 @@
 
 #include <wfmath/axisbox.h>
 
-#include "src/Model.h"
+#include "Model.h"
 
 #include "common/types.h"
 
+#include "renderers/RenderSystem.h"
+
 namespace Sear {
 
 class BoundBox : public Model {
@@ -36,30 +38,29 @@ public:
   /*
    * Creates the data arrays
    */ 
-  bool init(WFMath::AxisBox<3>, const std::string &type, bool wrap_texture);
+  int init(WFMath::AxisBox<3>, const std::string &type, bool wrap_texture);
 
   /*
    * Cleans up object
    */ 
-  void shutdown();
+  int shutdown();
   void render(bool); 
 
-  void invalidate();
+  void contextCreated();
+  void contextDestroyed(bool check);
 
-  bool useTextures() { return _use_textures; }
-  
 private:
-  std::string _type;
-  bool _use_textures;
-  static const int _num_points = 24; // NUmber of points in model
-  Vertex_3 _vertex_data[_num_points]; // Vertex data
-  Texel _texture_data[_num_points]; // Texture Co-oridinates data
-  Normal _normal_data[_num_points]; // Normal data
-  bool _initialised;
-  unsigned int _list;
-  unsigned int _list_select;
+  static const int m_num_points = 24; // NUmber of points in model
 
-  int texture;
+  bool m_initialised;
+  std::string m_texture_name;
+  TextureID m_texture_id;
+
+  Vertex_3 m_vertex_data[m_num_points]; // Vertex data
+  Texel m_texture_data[m_num_points]; // Texture Co-oridinates data
+  Normal m_normal_data[m_num_points]; // Normal data
+  unsigned int m_list;
+  unsigned int m_list_select;
 };
 
 } /* namespace Sear */
