@@ -1,22 +1,18 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2004 Simon Goodall
+// Copyright (C) 2001 - 2005 Simon Goodall
 
-// $Id: NPlane_Loader.cpp,v 1.17 2004/05/19 17:52:19 simon Exp $
-
-#ifdef HAVE_CONFIG_H
-  #include "config.h"
-#endif
+// $Id: NPlane_Loader.cpp,v 1.21 2005/06/29 21:19:41 simon Exp $
 
 #include <varconf/Config.h>
 
 #include "src/System.h"
 #include <string>
 
-#include "src/Render.h"
-#include "src/ModelHandler.h"
-#include "src/ModelRecord.h"
-#include "src/ObjectRecord.h"
+#include "renderers/Render.h"
+#include "ModelHandler.h"
+#include "ModelRecord.h"
+#include "ObjectRecord.h"
 
 #include "NPlane_Loader.h"
 #include "NPlane.h"
@@ -37,6 +33,7 @@ const std::string NPlane_Loader::NPLANE = "nplane";
 const std::string KEY_width = "width";
 const std::string KEY_height = "height";
 const std::string KEY_num_planes = "num_planes";
+const std::string KEY_texture = "texture";
 	
 NPlane_Loader::NPlane_Loader(ModelHandler *mh) {
   mh->registerModelLoader(NPLANE, this);
@@ -52,20 +49,24 @@ ModelRecord *NPlane_Loader::loadModel(Render *render, ObjectRecord *record, cons
   // Check that required fields exist
   if (!model_config.findItem(model_id, KEY_width)
     || !model_config.findItem(model_id, KEY_height)
-    || !model_config.findItem(model_id, KEY_num_planes)) {
+    || !model_config.findItem(model_id, KEY_num_planes)
+//    || !model_config.findItem(model_id, KEY_texture)
+  ) {
     std::cerr << "Error: Required fields missing for NPlane" << std::endl;
     return NULL;
   }
-  std::string type = record->type;
   // Create model instance
   NPlane *model = new NPlane(render);
   // Read config variables
   float width =  (double)model_config.getItem(model_id, KEY_width);
   float height =  (double)model_config.getItem(model_id, KEY_height);
   int num_planes = (int)model_config.getItem(model_id, KEY_num_planes);
+  std::string tex = record->type;
+  if (model_config.find(model_id, KEY_texture)) {
+    tex = (std::string)model_config.getItem(model_id, KEY_texture);
+  }
   // Initialise model
-  if (!model->init(type, num_planes, width, height)) {
-    model->shutdown();
+  if (model->init(tex, num_planes, width, height)) {
     delete model;
     return NULL;
   }
