@@ -1,8 +1,8 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2002 Simon Goodall, University of Southampton
+// Copyright (C) 2001 - 2006 Simon Goodall, University of Southampton
 
-// $Id: WireFrame.h,v 1.6 2004/04/26 15:45:20 simon Exp $
+// $Id: WireFrame.h,v 1.9 2006/01/28 15:35:49 simon Exp $
 
 #ifndef SEAR_WIREFRAME_H
 #define SEAR_WIREFRAME_H 1
@@ -11,7 +11,7 @@
 
 #include "common/types.h"
 
-#include "src/Model.h"
+#include "Model.h"
 
 namespace Sear {
 
@@ -20,18 +20,19 @@ public:
   WireFrame(Render*);
   ~WireFrame();
   
-  bool init(WFMath::AxisBox<3>);
-  void shutdown();
+  int init(WFMath::AxisBox<3>);
+  int shutdown();
  
-  void invalidate()  {}
+  void contextCreated();
+  void contextDestroyed(bool check);
  
   void render(bool);
-  bool useTextures() { return false; }
   
 private:
-  static const int _num_points = 32;
-  Vertex_3 _vertex_data[_num_points];
-  bool _initialised;
+  static const int m_num_points = 32;
+  bool m_initialised;
+  int m_disp;
+  Vertex_3 m_vertex_data[m_num_points];
 };
 
 } /* namespace Sear */
