@@ -1,12 +1,8 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2004 Simon Goodall
+// Copyright (C) 2001 - 2005 Simon Goodall
 
-// $Id: WireFrame_Loader.cpp,v 1.15 2004/04/27 15:07:01 simon Exp $
-
-#ifdef HAVE_CONFIG_H
-  #include "config.h"
-#endif
+// $Id: WireFrame_Loader.cpp,v 1.18 2005/04/13 12:16:04 simon Exp $
 
 #include <string>
 
@@ -14,10 +10,10 @@
 
 #include "common/Utility.h"
 
-#include "src/Model.h"
-#include "src/ModelHandler.h"
-#include "src/ModelRecord.h"
-#include "src/ObjectRecord.h"
+#include "Model.h"
+#include "ModelHandler.h"
+#include "ModelRecord.h"
+#include "ObjectRecord.h"
 
 #include "WireFrame_Loader.h"
 #include "WireFrame.h"
@@ -48,9 +44,9 @@ ModelRecord *WireFrame_Loader::loadModel(Render *render, ObjectRecord *record, c
   WireFrame *model = new WireFrame(render);
 
   WFMath::AxisBox<3> bbox = record->bbox;
-  if (!model->init(bbox)) {
+  if (model->init(bbox)) {
   //if (!model->init(bboxCheck(bbox))) {
-    model->shutdown();
+//    model->shutdown();
     delete model;
     return NULL;
   }
