@@ -1,16 +1,17 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2002 Simon Goodall
+// Copyright (C) 2001 - 2005 Simon Goodall
 
-// $Id: WireFrame_Loader.h,v 1.7 2002/11/12 23:59:22 simon Exp $
+// $Id: WireFrame_Loader.h,v 1.9 2005/03/15 17:55:04 simon Exp $
 
 #ifndef SEAR_WIREFRAME_LOADER_H
 #define SEAR_WIREFRAME_LOADER_H 1
 
-#include "src/ModelLoader.h"
+#include "ModelLoader.h"
 
 namespace Sear {
 
+class ModelHandler;
 // Forward Declarations
 	
 class WireFrame_Loader : public ModelLoader {
