@@ -1,12 +1,9 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2004 Simon Goodall, University of Southampton
+// Copyright (C) 2001 - 2006 Simon Goodall, University of Southampton
 
-// $Id: Cal3dCoreModel.cpp,v 1.22 2004/06/13 18:21:01 simon Exp $
+// $Id: Cal3dCoreModel.cpp,v 1.32 2006/01/28 15:35:49 simon Exp $
 
-#ifdef HAVE_CONFIG_H
-  #include "config.h"
-#endif
 
 #include "Cal3dModel.h"
 #include "Cal3dCoreModel.h"
@@ -19,9 +16,7 @@
 #include "src/FileHandler.h"
 #include "common/Utility.h"
 #include "src/System.h"
-#include "src/Render.h"
-
-#include "src/Exception.h"
+#include "renderers/Render.h"
 
 #include "renderers/RenderSystem.h"
 
@@ -64,38 +59,61 @@ static const std::string KEY_texture_map = "texture_map";
 static const std::string KEY_rotate = "rotate";
 	
 Cal3dCoreModel::Cal3dCoreModel() :
-  _initialised(false),
+  m_initialised(false),
   m_rotate(90.0f)
 {}
 
 Cal3dCoreModel::~Cal3dCoreModel() {
-  if (_initialised) shutdown();
+  assert(m_initialised == false);
+  //if (m_initialised) shutdown();
 }
 
-void Cal3dCoreModel::init(const std::string &filename) {
-  if (_initialised) shutdown();	
+int Cal3dCoreModel::init(const std::string &filename) {
+  assert(m_initialised == false);
+//  if (_initialised) shutdown();	
   // open the model configuration file
-  _core_model = new CalCoreModel();
+  m_core_model = new CalCoreModel("dummy");
   // create a core model instance
-  if(!_core_model->create("dummy")) {
+  if(!m_core_model) {
     CalError::printLastError();
-    return;
+    return 1;
   }
 //  std::cerr << "reading config" << std::endl << std::flush;
-  readConfig(filename);
- // std::cerr << "done reading config" << std::endl << std::flush;
-}
+  if (readConfig(filename)) {
+    printf("Error while loading %s\n", filename.c_str());
+    delete m_core_model;
+    m_core_model = NULL;
 
-void Cal3dCoreModel::shutdown() {
-  if (_core_model) {
-    _core_model->destroy();
-    delete _core_model;
-    _core_model = NULL;
+    return 1;
   }
-  _initialised = false;
+ // std::cerr << "done reading config" << std::endl << std::flush;
+
+  m_initialised = true;
+  return 0;
 }
 
-void Cal3dCoreModel::readConfig(const std::string &filename) {
+int Cal3dCoreModel::shutdown() {
+  assert(m_initialised == true);
+//  if (m_core_model) {
+    // Clean up user data
+    // Loop through each material
+    for (int i = 0; i < m_core_model->getCoreMaterialCount(); ++i) {
+      CalCoreMaterial *m = m_core_model->getCoreMaterial(i);
+      MapData *md;
+      // Loop through each map
+      for (int j = 0; j < m->getMapCount(); ++j) {
+        md = reinterpret_cast<MapData*>(m->getMapUserData(j));
+        if (md) delete md;
+      }
+    }
+    delete m_core_model;
+    m_core_model = NULL;
+//  }
+  m_initialised = false;
+  return 0;
+}
+
+int Cal3dCoreModel::readConfig(const std::string &filename) {
   varconf::Config config;
   config.sigsv.connect(SigC::slot(*this, &Cal3dCoreModel::varconf_callback));
   config.sige.connect(SigC::slot(*this, &Cal3dCoreModel::varconf_error_callback));
@@ -114,81 +132,84 @@ void Cal3dCoreModel::readConfig(const std::string &filename) {
     path = (std::string)config.getItem(SECTION_model, KEY_path);
     System::instance()->getFileHandler()->expandString(path);
   }
+
   // Load skeleton
-  if (!_core_model->loadCoreSkeleton(path + "/" + (std::string)config.getItem(SECTION_model, KEY_skeleton)))  {
+  if (m_core_model->loadCoreSkeleton(path + "/" + (std::string)config.getItem(SECTION_model, KEY_skeleton)) == 0)  {
     CalError::printLastError();
-    throw Exception();
-    return;
+    return 1;
   }
+
   // Get scale
   if (config.findItem(SECTION_model, KEY_scale)) {
-    _scale = (double)config.getItem(SECTION_model, KEY_scale);
+    m_scale = (double)config.getItem(SECTION_model, KEY_scale);
   } else {
-    _scale = 1.0f;
+    m_scale = 1.0f;
   }
   if (config.findItem(SECTION_model, KEY_rotate)) {
     m_rotate = (double)config.getItem(SECTION_model, KEY_rotate);
-printf("Rotate %f\n", m_rotate);
+    if (debug) printf("Rotate %f\n", m_rotate);
   }
+
   // Load all meshes 
-  for (MeshMap::const_iterator I = _meshes.begin(); I != _meshes.end(); ++I) {
+  for (MeshMap::const_iterator I = m_meshes.begin(); I != m_meshes.end(); ++I) {
     std::string mesh_name = I->first;
-    int mesh = _core_model->loadCoreMesh(path + (std::string)config.getItem(SECTION_model, KEY_mesh + "_" + mesh_name));
+    int mesh = m_core_model->loadCoreMesh(path + (std::string)config.getItem(SECTION_model, KEY_mesh + "_" + mesh_name));
     if (mesh == -1) {
       std::cerr << "Error loading mesh - " << path + (std::string)config.getItem(SECTION_model, KEY_mesh + "_" + mesh_name) << std::endl;
       CalError::printLastError();
     } else {
-      _meshes[mesh_name] = mesh;
+      m_meshes[mesh_name] = mesh;
     }
   }
+
   // Load all animations
-  for (AnimationMap::const_iterator I = _animations.begin(); I != _animations.end(); ++I) {
+  for (AnimationMap::const_iterator I = m_animations.begin(); I != m_animations.end(); ++I) {
     std::string animation_name = I->first;
-    int animation = _core_model->loadCoreAnimation(path + (std::string)config.getItem(SECTION_model, KEY_animation + "_" + animation_name));
+    int animation = m_core_model->loadCoreAnimation(path + (std::string)config.getItem(SECTION_model, KEY_animation + "_" + animation_name));
     if (animation == -1) {
       std::cerr << "Error loading animation - " << path + (std::string)config.getItem(SECTION_model, KEY_animation + "_" + animation_name) << std::endl;
       CalError::printLastError();
     } else {
-      _animations[animation_name] = animation;
+      m_animations[animation_name] = animation;
     }
   }
+
   // Load all materials
-  for (MaterialList::const_iterator I = _material_list.begin(); I != _material_list.end(); ++I) {
+  for (MaterialList::const_iterator I = m_material_list.begin();
+                                    I != m_material_list.end(); ++I) {
     std::string material_name = *I;
     int length =  material_name.find_first_of("_");
     std::string set = material_name.substr(0,length);
     std::string part = material_name.substr(length + 1);
-   std::cout << "Set: " << set << " - Part: " << part << std::endl;
-    int material = _core_model->loadCoreMaterial(path + (std::string)config.getItem(SECTION_model, KEY_material + "_" + material_name));
+//    if (debug) std::cout << "Set: " << set << " - Part: " << part << std::endl;
+    int material = m_core_model->loadCoreMaterial(path + (std::string)config.getItem(SECTION_model, KEY_material + "_" + material_name));
     if (material == -1) {
       std::cerr << "Error loading material - " << path + (std::string)config.getItem(SECTION_model, KEY_material + "_" + material_name) << std::endl;
       CalError::printLastError();
     } else {
-      _materials[set][part] = material;
+      m_materials[set][part] = material;
     }
     // Create material thread and assign material to a set;
-    if (_sets[set] == 0) {
-      _sets[set] = set_counter++;
-//      if (debug)
- std::cout << "Creating set " << set << " with id  " << _sets[set] << std::endl;
+    if (m_sets[set] == 0) {
+      m_sets[set] = set_counter++;
+//      if (debug) std::cout << "Creating set " << set << " with id  " << m_sets[set] << std::endl;
     }
-    if (_parts[part] == 0) {
-      _parts[part] = part_counter++;
-//      if (debug)
- std::cout << "Creating part " << part << " with id  " << _parts[part] << std::endl;
+    if (m_parts[part] == 0) {
+      m_parts[part] = part_counter++;
+//      if (debug) std::cout << "Creating part " << part << " with id  " << m_parts[part] << std::endl;
     }
-    _core_model->createCoreMaterialThread(_parts[part] - 1);
+    m_core_model->createCoreMaterialThread(m_parts[part] - 1);
 //     _core_model->createCoreMaterialThread(material);
     // initialize the material thread
-    _core_model->setCoreMaterialId(_parts[part] - 1, _sets[set] - 1, material);
+    m_core_model->setCoreMaterialId(m_parts[part] - 1, m_sets[set] - 1, material);
   }
   // Check for custom material settings
-  for (MaterialsMap::const_iterator I = _materials.begin(); I != _materials.end(); ++I) {
+  for (MaterialsMap::const_iterator I = m_materials.begin(); I != m_materials.end(); ++I) {
     std::string set = I->first;
     for (MaterialMap::const_iterator J = I->second.begin(); J != I->second.end(); ++J) {
       std::string part = J->first;
       std::string section = SECTION_material + "_" + set + "_" + part;
-      CalCoreMaterial *material = _core_model->getCoreMaterial(J->second);
+      CalCoreMaterial *material = m_core_model->getCoreMaterial(J->second);
       if (!material) continue;
       // Check all keys
       if (config.findItem(section, KEY_ambient_red)) {
@@ -235,6 +256,8 @@ printf("Rotate %f\n", m_rotate);
         material->setShininess((double)config.getItem(section, KEY_shininess));
       }
       // Load textures
+      // TODO this limit should not be hardcoded!
+      // Need to query object
       for (int i = 0; i < 2; ++i) {
 	std::string key = KEY_texture_map + "_" + string_fmt(i);
         if (config.findItem(section, key)) { // Is texture name over-ridden?
@@ -247,35 +270,56 @@ printf("Rotate %f\n", m_rotate);
               std::cerr << "Error setting map data" << std::endl;
             }
 	  }
-          if (!material->setMapUserData(i, (Cal::UserData)textureId)) {
+          MapData *md = new MapData();
+          md->textureID = textureId;
+          if (!material->setMapUserData(i, reinterpret_cast<Cal::UserData>(md))) {
             std::cerr << "Error setting map user data" << std::endl;
 	  }
         } else { // Use default texture
           std::string texture = material->getMapFilename(i);
 	  if (texture.empty()) continue;
           unsigned int textureId = loadTexture(texture);
-          if (!material->setMapUserData(i, (Cal::UserData)textureId)) {
+          MapData *md = new MapData();
+          md->textureID = textureId;
+          if (!material->setMapUserData(i, reinterpret_cast<Cal::UserData>(md))) {
             std::cerr << "Error setting map user data" << std::endl;
 	  }
 	}
       }
     }
   }
+
+  return 0;
 }
 
 void Cal3dCoreModel::varconf_callback(const std::string &section, const std::string &key, varconf::Config &config) {
   if (section == SECTION_model) {
     if (key == KEY_mesh) {}
     else if (key.substr(0, KEY_mesh.size()) == KEY_mesh) {
-      _meshes[key.substr(KEY_mesh.size() + 1)] = 0;
+      m_meshes[key.substr(KEY_mesh.size() + 1)] = 0;
     }
     if (key == KEY_animation) {}
     else if (key.substr(0, KEY_animation.size()) == KEY_animation) {
-      _animations[key.substr(KEY_animation.size() + 1)] = 0;
+      m_animations[key.substr(KEY_animation.size() + 1)] = 0;
     }
     if (key == KEY_material) {}
     else if (key.substr(0, KEY_material.size()) == KEY_material) {
-      _material_list.push_back(key.substr(KEY_material.size() + 1));;
+      m_material_list.push_back(key.substr(KEY_material.size() + 1));;
+    }
+  } else {
+    
+    // Add animations weights to map
+    // Get weight value
+    varconf::Variable temp = config.getItem(section, key);
+    std::string sec = section.substr(KEY_animation.size() + 1);
+    if (section.substr(0, KEY_animation.size()) == KEY_animation) {
+      if (temp.is_double()) {
+        // Get animation name
+        std::string k = key.substr(KEY_animation.size() + 1);
+        // Add pair to map.
+         printf("Adding animation: %s %s %f\n", section.c_str() , k.c_str(), (double)temp);
+        m_anims[sec].push_back(AnimWeight(k, (double)temp));
+      }
     }
   }
 }
@@ -292,7 +336,10 @@ unsigned int Cal3dCoreModel::loadTexture(const std::string& strFilename) {
 
 Cal3dModel *Cal3dCoreModel::instantiate() {
   Cal3dModel *model = new Cal3dModel(RenderSystem::getInstance().getRenderer());
-  model->init(this);
+  if (model->init(this)) {
+    delete model;
+    model = NULL;
+  }
   return model;
 }
 
