@@ -1,8 +1,8 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2003 Simon Goodall, University of Southampton
+// Copyright (C) 2001 - 2006 Simon Goodall, University of Southampton
 
-// $Id: Cal3dModel.h,v 1.7 2004/06/13 18:21:01 simon Exp $
+// $Id: Cal3dModel.h,v 1.17 2006/01/28 15:35:49 simon Exp $
 
 #ifndef SEAR_LOADERS_CAL3D_CAL3DMODEL_H
 #define SEAR_LOADERS_CAL3D_CAL3DMODEL_H 1
@@ -12,8 +12,8 @@
 
 #include <cal3d/cal3d.h>
 #include "Cal3dCoreModel.h"
-#include "src/Model.h"
-#include "src/Graphics.h"
+#include "Model.h"
+#include "renderers/Graphics.h"
 
 
 namespace Sear {
@@ -26,10 +26,11 @@ public:
   Cal3dModel(Render *);
   ~Cal3dModel();
 
-  bool init(Cal3dCoreModel *);
-  void shutdown();
+  int init(Cal3dCoreModel *);
+  int shutdown();
 
-  void invalidate() {}
+  void contextCreated() {}
+  void contextDestroyed(bool check) {}
 
   float getLodLevel() const { return m_lodLevel; }
   float getScale() const { return m_renderScale; }
@@ -40,23 +41,21 @@ public:
   void setLodLevel(float lodLevel);
 
   void action(const std::string &action);
-  void setAppearance(Atlas::Message::Element::MapType &map);
+  void animate(const std::string &action);
+  void setAppearance(const Atlas::Message::MapType &map);
   Graphics::RotationStyle rotationStyle() { return Graphics::ROS_NORMAL; }
  
-  void setHeight(float height) { _height = height; }
-  float getHeight() const { return _height; }
-
-  unsigned int getPartID(const std::string &part) { return _core_model->_parts[part]; }
-  unsigned int getSetID(const std::string &set) { return _core_model->_sets[set]; }
+  unsigned int getPartID(const std::string &part) { return m_core_model->m_parts[part]; }
+  unsigned int getSetID(const std::string &set) { return m_core_model->m_sets[set]; }
   
   void setMaterialSet(const std::string &set) {
-    setMaterialSet(_core_model->_sets[set]);
+    setMaterialSet(m_core_model->m_sets[set]);
   }
   
   void setMaterialSet(unsigned int set);
   
   void setMaterialPartSet(const std::string &mesh, const std::string &set) {
-    setMaterialPartSet(_core_model->_meshes[mesh], _core_model->_sets[set]);
+    setMaterialPartSet(m_core_model->m_meshes[mesh], m_core_model->m_sets[set]);
   }
   void setMaterialPartSet(unsigned int part, unsigned int set);
  
@@ -65,21 +64,22 @@ public:
 
   void setRotate(float r) { m_rotate = r; }
   
+  virtual PosAndOrient getPositionForSubmodel(const std::string& submodelName);
+
+  void addAnimation(const Cal3dCoreModel::WeightList &list);
+  void removeAnimation(const Cal3dCoreModel::WeightList &list);
 private:
   void renderMesh(bool bWireframe, bool bLight, bool);
 
-  bool _initialised;
+  bool m_initialised;
 
-  Cal3dCoreModel *_core_model;
-  float _height;
-  CalModel m_calModel;
+  Cal3dCoreModel *m_core_model;
+  CalModel *m_calModel;
   float m_lodLevel;
   float m_renderScale;
-//  static float _walk_blend[];
-//  static float _run_blend[];
-//  static float _strut_blend[];
   float m_rotate;
-  std::string current_head;
+  //std::string current_head;
+  std::string m_cur_anim;
 };
 
 
