@@ -1,13 +1,13 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2002 Simon Goodall
+// Copyright (C) 2001 - 2005 Simon Goodall
 
-// $Id: Cal3d_Loader.h,v 1.1 2003/03/05 23:39:04 simon Exp $
+// $Id: Cal3d_Loader.h,v 1.3 2005/03/15 17:55:04 simon Exp $
 
 #ifndef SEAR_CAL3D_LOADER_H
 #define SEAR_CAL3D_LOADER_H 1
 
-#include "src/ModelLoader.h"
+#include "ModelLoader.h"
 
 namespace Sear {
 // Forward Declarations
@@ -24,7 +24,7 @@ public:
 
 private:
   static const std::string CAL3D;
-  CoreModelHandler *_core_model_handler;
+  CoreModelHandler *m_core_model_handler;
   
 };
 
