@@ -1,8 +1,8 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2003 Simon Goodall
+// Copyright (C) 2001 - 2005 Simon Goodall
 
-// $Id: CoreModelHandler.h,v 1.5 2003/03/14 11:02:42 simon Exp $
+// $Id: CoreModelHandler.h,v 1.6 2005/03/15 17:55:04 simon Exp $
 
 #ifndef SEAR_LOADERS_CAL3D_COREMODELHANDLER_H
 #define SEAR_LOADERS_CAL3D_COREMODELHANDLER_H 1
@@ -22,16 +22,16 @@ public:
   CoreModelHandler();
   ~CoreModelHandler();
 
-  void init();
-  void shutdown();
+  int init();
+  int shutdown();
 
   void loadCoreModel(const std::string &filename);
   Cal3dModel *instantiateModel(const std::string &model);
     
 private:
-  bool _initialised;
   typedef std::map <std::string, Cal3dCoreModel*> CoreModelMap;
-  CoreModelMap _core_models;
+  bool m_initialised;
+  CoreModelMap m_core_models;
   
 };
 	
