@@ -1,10 +1,12 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2004 Simon Goodall, University of Southampton
+// Copyright (C) 2001 - 2005 Simon Goodall, University of Southampton
 
 #ifndef SEAR_GL_RENDER_H
 #define SEAR_GL_RENDER_H 1
 
+#include <Eris/EntityRef.h>
+
 #include <sage/sage.h>
 #include <sage/GL.h>
 
@@ -20,10 +22,12 @@
 #include <wfmath/axisbox.h>
 #include <wfmath/quaternion.h>
 
-#include "src/Light.h"
-#include "src/Render.h"
+#include "Light.h"
+#include "Render.h"
 #include "RenderSystem.h"
 
+
+
 namespace Sear {
 
 class System;
@@ -36,12 +40,15 @@ class ModelRecord;
 class Console;
 
 class GL : public Render, public SigC::Object {
-public:GL();
-~GL();
+public:
+  GL();
+  ~GL();
   void init();
-  void initContext();
   void shutdown();
-  void invalidate();
+
+  int contextCreated();
+  void contextDestroyed(bool check);
+
   bool createWindow(unsigned int width, unsigned int height, bool fullscreen);
   void destroyWindow();
   void toggleFullscreen();
@@ -56,7 +63,11 @@ private:
   bool m_fullscreen;
   SDL_Surface *m_screen;
 
-  static void checkError();
+  /**
+   * Checks to see if OpenGL logged an error.
+   * @return 1 on error, 0 otherwise.
+   */
+  static int checkError();
 
 
 public:
@@ -67,31 +78,35 @@ public:
 
   void initLighting();
   void initFont();
-  void shutdownFont();
+  void shutdownFont(bool check);
   void print(int x, int y, const char*, int set);
   void print3D(const char* string, int set);
   inline void newLine();
 
+  void getScreenCoords(int & x, int & y, double z_offset);
+
   void buildColourSet();
   void drawTextRect(int, int, int, int, int);
   float distFromNear(float,float,float);  
   void setColour(float red, float green, float blue, float alpha) { glColor4f(red, green, blue, alpha); }
 
-  int patchInFrustum(const WFMath::AxisBox<3> &);
+  int axisBoxInFrustum(const WFMath::AxisBox<3> &bbox);
   
   void procEvent(int, int);
-  int getWindowWidth() { return m_width; }
-  int getWindowHeight() { return m_height; }
+  int getWindowWidth() const { return m_width; }
+  int getWindowHeight() const { return m_height; }
+  bool isFullScreen() const { return m_fullscreen; }
 
-  std::string getActiveID();// { return activeID; }
+  std::string getActiveID() const;// { return activeID; }
+  WorldEntity *getActiveEntity() const;// { return activeID; }
   void checkModelStatus(const std::string &) {}
   void setModelInUse(const std::string &, bool) {}
 
-  void readConfig();
-  void writeConfig();
+  void readConfig(varconf::Config &config);
+  void writeConfig(varconf::Config &config);
   void setupStates();
 
-  float getLightLevel() { return _light_level; }
+  float getLightLevel() { return m_light_level; }
 
   void translateObject(float x, float y, float z);
   void rotate(float angle, float x, float y, float z);
@@ -102,8 +117,9 @@ public:
   void setMaterial(float *ambient, float *diffuse, float *specular, float shininess, float *emissive);
   void renderArrays(unsigned int type, unsigned int offset, unsigned int number_of_points, Vertex_3 *vertex_data, Texel *texture_data, Normal *normal_data, bool multitexture);
   void renderElements(unsigned int type, unsigned int number_of_points, int *faces_data, Vertex_3 *vertex_data, Texel *texture_data, Normal *normal_data, bool multitexture);
-  void drawQueue(QueueMap &queue, bool select_mode, float time_elapsed);
+  void drawQueue(QueueMap &queue, bool select_mode);
   void drawMessageQueue(MessageList &list);
+  void drawNameQueue(MessageList &list);
   void drawOutline(ModelRecord *);
  
   inline void store();
@@ -117,34 +133,38 @@ public:
   inline void renderActiveName();
   inline void applyCharacterLighting(float x, float y, float z);
   inline void getFrustum(float [6][4]);
+  virtual void getModelviewMatrix(float m[4][4]);
  
   void beginRecordList(unsigned int list) { glNewList(list, GL_COMPILE_AND_EXECUTE); }
   void endRecordList() { glEndList(); }
   void playList(unsigned int list) { glCallList(list); }
   unsigned int getNewList() { return glGenLists(1); }
   void freeList(unsigned int list) { if (glIsList(list)) glDeleteLists(list, 1); };
+  void selectTerrainColour(WorldEntity * we);
   void resize(int width, int height);
 
+  bool getWorldCoords(int x, int y, float &wx, float &wy,float &wz);
+
 protected:
-  System *_system;
-  Graphics *_graphics;
+  System *m_system;
+  Graphics *m_graphics;
 
-  const float fov;
-  const float near_clip;
-  float _far_clip_dist;
+  const float m_fov;
+  float m_near_clip;
+  float m_far_clip_dist;
 
-  GLuint base;
+  GLuint m_base;
 
-  int font_id;
-  int splash_id;
+  int m_font_id;
+  int m_splash_id;
 
-  float frustum[6][4];
+  float m_frustum[6][4];
   
 //  std::string activeID;
-  std::string active_name;
-  WorldEntity *activeEntity;
-  int x_pos;
-  int y_pos;
+  std::string m_active_name;
+  Eris::EntityRef m_activeEntity;
+  int m_x_pos;
+  int m_y_pos;
   
   
   void buildQueues(WorldEntity*, int, bool);
@@ -155,35 +175,38 @@ protected:
     LIGHT_LAST
   } lightSources;
 
-  Light lights[LIGHT_LAST];
+  Light m_lights[LIGHT_LAST];
 
-  float _speech_offset_x;
-  float _speech_offset_y;
-  float _speech_offset_z;
+  float m_speech_offset_x;
+  float m_speech_offset_y;
+  float m_speech_offset_z;
 
-  float _fog_start;
-  float _fog_end;
-  float _light_level;
+  float m_fog_start;
+  float m_fog_end;
+  float m_light_level;
 
   static const unsigned int NUM_COLOURS = 512;
-  GLubyte colourArray[NUM_COLOURS][3];
-  WorldEntity *entityArray[NUM_COLOURS];
-  unsigned int colour_index;
-  std::map<unsigned int, std::string> colour_mapped;
+  GLubyte m_colourArray[NUM_COLOURS][3];
+  WorldEntity *m_entityArray[NUM_COLOURS];
+  unsigned int m_colour_index;
+  std::map<unsigned int, std::string> m_colour_mapped;
   
-  GLint redBits, greenBits, blueBits;
-  GLuint redMask, greenMask, blueMask;
-  int redShift, greenShift, blueShift;
+  GLint m_redBits, m_greenBits, m_blueBits;
+  GLuint m_redMask, m_greenMask, m_blueMask;
+  int m_redShift, m_greenShift, m_blueShift;
   
-  inline static  GLuint makeMask(GLuint bits);
-  inline void resetColours();
-  inline WorldEntity *getSelectedID(unsigned int i);
+  static GLuint makeMask(GLuint bits) {
+    // Create an 8-bit mask with 'bits' set to 1
+    return (0xFF >> (8 - bits));
+  }
+  void resetColours() { m_colour_index = 1; }
+  WorldEntity *getSelectedID(unsigned int i) const  {
+    return (i >= NUM_COLOURS) ? (NULL) : (m_entityArray[i]);
+  }
   void nextColour(WorldEntity*);
 
-  void setupExtensions();
-  bool use_ext_texture_filter_anisotropic;
-  bool use_sgis_generate_mipmap;
-  bool _multi_texture_mode;
+  int setupExtensions();
+  bool m_use_fsaa;
   bool m_initialised;
   
   void varconf_callback(const std::string &section, const std::string &key, varconf::Config &config);
