@@ -1,18 +1,14 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2004 Simon Goodall, University of Southampton
+// Copyright (C) 2001 - 2006 Simon Goodall, University of Southampton
 
-// $Id: StateManager.cpp,v 1.17 2004/05/24 18:47:11 alriddoch Exp $
+// $Id: StateManager.cpp,v 1.26 2006/01/28 15:35:49 simon Exp $
 
 /*
  * TODO
  * custom of default settings
  * */
 
-#ifdef HAVE_CONFIG_H
-  #include "config.h"
-#endif
-
 #include <sage/sage.h>
 #include <sage/GL.h>
 
@@ -49,6 +45,7 @@ static const std::string TWO_SIDED_LIGHTING = "two_sided_lighting";
 static const std::string TEXTURE = "texture_";
 static const std::string COLOUR_MATERIAL = "colour_material";
 static const std::string DEPTH_TEST = "depth_test";
+static const std::string DEPTH_WRITE = "depth_write";
 static const std::string CULL_FACE = "cull_face";
 static const std::string CULL_FACE_CW = "cull_face_cw";
 static const std::string STENCIL = "stencil";
@@ -84,31 +81,32 @@ static const std::string BLEND_src_alpha_saturate = "src_alpha_saturate";
 static const std::string CMD_LOAD_STATE_CONFIG = "load_state_file";
 
 StateManager::StateManager() :
-  _initialised(false),
-  _current_state(-1),
-  _state_counter(1)
+  m_initialised(false),
+  m_current_state(-1),
+  m_state_counter(1)
 {}
 
 StateManager::~StateManager() {
-  if (_initialised) shutdown();
+  assert(m_initialised == false);
 }
 
-void StateManager::init() {
-  assert(_initialised == false);
-  if (_initialised) shutdown();
+int StateManager::init() {
+  assert(m_initialised == false);
+
   if (debug) std::cout << "State Loader: Initialising." << std::endl;
 
-  _current_state = -1;
-  _state_counter = 1;
+  m_current_state = -1;
+  m_state_counter = 1;
 
-  _states.resize(256);
-  _name_state_vector.resize(256);
-  _state_change_vector.resize(256);
-  for (unsigned int i = 0; i < 256; _state_change_vector[i++].resize(256));
+  m_states.resize(256);
+  m_name_state_vector.resize(256);
+  m_state_change_vector.resize(256);
+  for (unsigned int i = 0; i < 256; m_state_change_vector[i++].resize(256));
   
   StateProperties *default_state = new StateProperties;
   StateProperties *font_state = new StateProperties;
   StateProperties *select_state = new StateProperties;
+  StateProperties *cursor_state = new StateProperties;
   // Create a default record
   default_state->state = "default";
   default_state->alpha_test = false;
@@ -120,6 +118,7 @@ void StateManager::init() {
     default_state->textures[i] = false;
   default_state->colour_material = false;
   default_state->depth_test = false;
+  default_state->depth_write = true;
   default_state->cull_face = false;
   default_state->cull_face_cw = false;
   default_state->stencil = false;
@@ -129,10 +128,10 @@ void StateManager::init() {
   default_state->alpha_value = 0.1f;
   default_state->blend_src_function = GL_SRC_ALPHA;
   default_state->blend_dest_function = GL_ONE_MINUS_SRC_ALPHA;
-  _states[_state_counter] = default_state;
-  _state_name_map[default_state->state] = _state_counter;
-  _name_state_vector[_state_counter] = default_state->state;
-  ++_state_counter;
+  m_states[m_state_counter] = default_state;
+  m_state_name_map[default_state->state] = m_state_counter;
+  m_name_state_vector[m_state_counter] = default_state->state;
+  ++m_state_counter;
   
   //Create a font state so we can still see text
   //even if no files have been loaded into Sear
@@ -146,6 +145,7 @@ void StateManager::init() {
     font_state->textures[i] = false;
   font_state->colour_material = false;
   font_state->depth_test = false;
+  font_state->depth_write = true;
   font_state->cull_face = false;
   font_state->cull_face_cw = false;
   font_state->stencil = false;
@@ -155,13 +155,12 @@ void StateManager::init() {
   font_state->alpha_value = 0.1f;
   font_state->blend_src_function = GL_SRC_ALPHA;
   font_state->blend_dest_function = GL_ONE_MINUS_SRC_ALPHA;
-  _states[_state_counter] = font_state;
-  _state_name_map[font_state->state] = _state_counter;
-  _name_state_vector[_state_counter] = font_state->state;
-  ++_state_counter;
+  m_states[m_state_counter] = font_state;
+  m_state_name_map[font_state->state] = m_state_counter;
+  m_name_state_vector[m_state_counter] = font_state->state;
+  ++m_state_counter;
  
-  //Create a font state so we can still see text
-  //even if no files have been loaded into Sear
+  // Create default select mode state
   select_state->state = "select";
   select_state->alpha_test = false;
   select_state->blend = false;
@@ -171,6 +170,7 @@ void StateManager::init() {
     select_state->textures[i] = false;
   select_state->colour_material = false;
   select_state->depth_test = true;
+  select_state->depth_write = true;
   select_state->cull_face = false;
   select_state->cull_face_cw = false;
   select_state->stencil = false;
@@ -180,29 +180,58 @@ void StateManager::init() {
   select_state->alpha_value = 0.1f;
   select_state->blend_src_function = GL_SRC_ALPHA;
   select_state->blend_dest_function = GL_ONE_MINUS_SRC_ALPHA;
-  _states[_state_counter] = select_state;
-  _state_name_map[select_state->state] = _state_counter;
-  _name_state_vector[_state_counter] = select_state->state;
-  ++_state_counter;
+  m_states[m_state_counter] = select_state;
+  m_state_name_map[select_state->state] = m_state_counter;
+  m_name_state_vector[m_state_counter] = select_state->state;
+  ++m_state_counter;
 
-  _initialised = true;
+  // Create default state for mouse cursor
+  cursor_state->state = "cursor";
+  cursor_state->alpha_test = true;
+  cursor_state->blend = false;
+  cursor_state->lighting = false;
+  cursor_state->two_sided_lighting = false;
+  for (unsigned int  i = 1; i < MAX_UNITS; ++i)
+    cursor_state->textures[i] = false;
+  cursor_state->textures[0] = true;
+  cursor_state->colour_material = false;
+  cursor_state->depth_test = false;
+  cursor_state->depth_write = true;
+  cursor_state->cull_face = false;
+  cursor_state->cull_face_cw = false;
+  cursor_state->stencil = false;
+  cursor_state->fog = false;
+  cursor_state->rescale_normals = false;
+  cursor_state->alpha_function = GL_GREATER;
+  cursor_state->alpha_value = 0.1f;
+  cursor_state->blend_src_function = GL_SRC_ALPHA;
+  cursor_state->blend_dest_function = GL_ONE_MINUS_SRC_ALPHA;
+  m_states[m_state_counter] = cursor_state;
+  m_state_name_map[cursor_state->state] = m_state_counter;
+  m_name_state_vector[m_state_counter] = cursor_state->state;
+  ++m_state_counter;
+
+
+  m_initialised = true;
+  return 0;
 }
 
-void StateManager::shutdown() {
-  assert(_initialised);
+int StateManager::shutdown() {
+  assert(m_initialised == true);
   if (debug) std::cout << "State Loader: Shutdown" << std::endl;
-  while (!_states.empty()) {
-//    if (*_states.begin()) {
-      StateProperties *sp = *(_states.begin());
+  while (!m_states.empty()) {
+//    if (*m_states.begin()) {
+      StateProperties *sp = *(m_states.begin());
       delete sp;
   //  }
-    _states.erase(_states.begin());
+    m_states.erase(m_states.begin());
   }
-  _initialised = false;
+  m_initialised = false;
+  return 0;
 }
 
 void StateManager::readFiles(const std::string &file_name) {
-  assert(_initialised);
+  assert(m_initialised);
   varconf::Config config;
   config.sigsv.connect(SigC::slot(*this, &StateManager::varconf_callback));
   config.sige.connect(SigC::slot(*this, &StateManager::varconf_error_callback));
@@ -210,9 +239,9 @@ void StateManager::readFiles(const std::string &file_name) {
 }
 
 void StateManager::varconf_callback(const std::string &section, const std::string &key, varconf::Config &config) {
-  assert(_initialised);
-  int in = _state_name_map[section];
-  StateProperties *record = _states[_state_name_map[section]];
+  assert(m_initialised);
+  int in = m_state_name_map[section];
+  StateProperties *record = m_states[m_state_name_map[section]];
   // If record does not exist, create it.
 //  if (!record) {
   if (in == 0) {
@@ -227,6 +256,7 @@ void StateManager::varconf_callback(const std::string &section, const std::strin
         record->textures[i] = false;
       record->colour_material = false;
       record->depth_test = false;
+      record->depth_write = true;
       record->cull_face = false;
       record->cull_face_cw = false;
       record->stencil = false;
@@ -237,10 +267,10 @@ void StateManager::varconf_callback(const std::string &section, const std::strin
       record->blend_src_function = GL_SRC_ALPHA;
       record->blend_dest_function = GL_ONE_MINUS_SRC_ALPHA;
   
-      _states[_state_counter] = record;
-      _state_name_map[record->state] = _state_counter;
-      _name_state_vector[_state_counter] = record->state;
-      ++_state_counter;
+      m_states[m_state_counter] = record;
+      m_state_name_map[record->state] = m_state_counter;
+      m_name_state_vector[m_state_counter] = record->state;
+      ++m_state_counter;
       if (debug) std::cout << "Adding State: " << section << std::endl;
   }
 
@@ -250,6 +280,7 @@ void StateManager::varconf_callback(const std::string &section, const std::strin
   else if (key == TWO_SIDED_LIGHTING) record->two_sided_lighting = (bool)config.getItem(section, key);
   else if (key == COLOUR_MATERIAL) record->colour_material = (bool)config.getItem(section, key);
   else if (key == DEPTH_TEST) record->depth_test = (bool)config.getItem(section, key);
+  else if (key == DEPTH_WRITE) record->depth_write = (bool)config.getItem(section, key);
   else if (key == CULL_FACE) record->cull_face = (bool)config.getItem(section, key);
   else if (key == CULL_FACE_CW) record->cull_face_cw = (bool)config.getItem(section, key);
   else if (key == STENCIL) record->stencil = (bool)config.getItem(section, key);
@@ -277,9 +308,9 @@ void StateManager::varconf_error_callback(const char *message) {
 }
 
 StateID StateManager::getState(const std::string &state_name) const {
-  assert(_initialised);
-  StateNameMap::const_iterator S = _state_name_map.find(state_name);
-  if (S == _state_name_map.end()) {
+  assert(m_initialised);
+  StateNameMap::const_iterator S = m_state_name_map.find(state_name);
+  if (S == m_state_name_map.end()) {
     std::cerr << "state " << state_name << " is unknown" << std::endl;
     return 1;
   }
@@ -317,25 +348,27 @@ int StateManager::getBlendFunction(const std::string &blend_function) {
 }
 
 void StateManager::stateChange(StateID state) {
-  assert(_initialised == true);
-  if (_current_state == state) return; // No need to do anything
-  StateProperties *sp = _states[state];
+  assert(m_initialised == true);
+  if (m_current_state == state) return; // No need to do anything
+
+  assert (state < m_states.size());
+  StateProperties *sp = m_states[state];
   // If state doesn't exist, take first one
   assert(sp);
   if (!sp) {
     std::cout << "bad state found - " << state <<  std::endl;
-    sp = _states[1];
+    sp = m_states[1];
     state = 1;
   }
   assert(sp != NULL);
   // First time round, we have no states
-  if (_current_state != -1) {
-    unsigned int list = _state_change_vector[_current_state][state];
+  if (m_current_state != -1) {
+    unsigned int list = m_state_change_vector[m_current_state][state];
     // Check whether we need to generate a display list
     if (!glIsList(list)) {
       list = glGenLists(1);
-      buildStateChange(list, _states[_current_state], sp);
-      _state_change_vector[_current_state][state] = list;
+      buildStateChange(list, m_states[m_current_state], sp);
+      m_state_change_vector[m_current_state][state] = list;
     }
     glCallList(list);
   } else {
@@ -358,8 +391,11 @@ void StateManager::stateChange(StateID state) {
     }
     if (sp->colour_material) glEnable(GL_COLOR_MATERIAL);
     else glDisable(GL_COLOR_MATERIAL);
+    
     if (sp->depth_test) glEnable(GL_DEPTH_TEST);
     else glDisable(GL_DEPTH_TEST);
+    glDepthMask(sp->depth_write);
+        
     if (sp->cull_face) glEnable(GL_CULL_FACE);
     else glDisable(GL_CULL_FACE);
     if (sp->cull_face_cw) glFrontFace(GL_CW);
@@ -378,11 +414,11 @@ void StateManager::stateChange(StateID state) {
       glBlendFunc(sp->blend_src_function, sp->blend_dest_function);
   //  }
   }
-  _current_state = state;
+  m_current_state = state;
 }
 
 void StateManager::buildStateChange(unsigned int &list, StateProperties *previous_state, StateProperties *next_state) {
-  assert(_initialised);
+  assert(m_initialised);
   assert (previous_state != NULL);
   assert (next_state != NULL);
   glNewList(list, GL_COMPILE);
@@ -421,6 +457,11 @@ void StateManager::buildStateChange(unsigned int &list, StateProperties *previou
     if (next_state->depth_test) glEnable(GL_DEPTH_TEST);
     else glDisable(GL_DEPTH_TEST);
   }
+  
+  if (previous_state->depth_write != next_state->depth_write) {
+    glDepthMask(next_state->depth_write);
+  }
+  
   if (previous_state->cull_face != next_state->cull_face) {
     if (next_state->cull_face) glEnable(GL_CULL_FACE);
     else glDisable(GL_CULL_FACE);
@@ -448,12 +489,13 @@ void StateManager::buildStateChange(unsigned int &list, StateProperties *previou
 }
 
 void StateManager::registerCommands(Console *console) {
-  assert(_initialised);
+  assert(m_initialised);
+  assert(console != NULL);
   console->registerCommand(CMD_LOAD_STATE_CONFIG, this);
 }
 
 void StateManager::runCommand(const std::string &command, const std::string &arguments) {
-  assert(_initialised);
+  assert(m_initialised);
   if (command == CMD_LOAD_STATE_CONFIG) {
     std::string a = arguments;
     System::instance()->getFileHandler()->expandString(a);
@@ -461,19 +503,23 @@ void StateManager::runCommand(const std::string &command, const std::string &arg
   }
 }
 
-void StateManager::invalidate() {
-  assert(_initialised);
-  for (unsigned int i = 0; i < _state_change_vector.size(); ++i) {
-    for (unsigned int j = 0; j < _state_change_vector[i].size(); ++j) {
+
+void StateManager::contextCreated() {
+  assert(m_initialised);
+}
+void StateManager::contextDestroyed(bool check) {
+  assert(m_initialised);
+  for (unsigned int i = 0; i < m_state_change_vector.size(); ++i) {
+    for (unsigned int j = 0; j < m_state_change_vector[i].size(); ++j) {
       // Delete display list if its still valid
-      if (glIsList(_state_change_vector[i][j])) {
-        glDeleteLists(_state_change_vector[i][j], 1);
+      if (check && glIsList(m_state_change_vector[i][j])) {
+        glDeleteLists(m_state_change_vector[i][j], 1);
       }
       // reset list value
-      _state_change_vector[i][j] = 0; 
+      m_state_change_vector[i][j] = 0; 
     }
   }
-  _current_state = -1;
+  m_current_state = -1;
 }
 
 } /* namespace Sear */
