@@ -1,12 +1,8 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2004 Simon Goodall, University of Southampton
+// Copyright (C) 2001 - 2005 Simon Goodall, University of Southampton
 
-// $Id: TextureManager.cpp,v 1.31 2004/07/14 10:10:31 simon Exp $
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+// $Id: TextureManager.cpp,v 1.42 2006/01/28 15:35:49 simon Exp $
 
 #include "TextureManager.h"
 
@@ -35,7 +31,7 @@ int ilogb(double x)
 // Default texture maps
 #include "default_image.xpm"
 #include "default_font.h"
-
+#include "cursors.h"
 
 #ifdef USE_MMGR
 #include "common/mmgr.h"
@@ -52,6 +48,19 @@ static const bool debug = false;
 #endif
 namespace Sear {
 
+// Find the next largest power of 2 to i, but no bigger than the max texture
+// size we are allowed
+inline int scaleDimension(int i) {
+  GLint texSize;
+  glGetIntegerv(GL_MAX_TEXTURE_SIZE, &texSize);
+  int n = 2;
+  while (n < i && n <= texSize) {
+    n <<= 1;
+  }
+  if (n > texSize) return texSize;
+  else return n;
+}
+
 // Config section name
 static const std::string SECTION_texture_manager = "texture_manager";
 static const std::string SECTION_render = "render";
@@ -162,12 +171,13 @@ void TextureManager::init()
   m_names.resize(1); // ditto
 
   m_texture_map.clear();
-  
+ 
+  m_texture_config.sige.connect(SigC::slot(*this, &TextureManager::varconf_error_callback));
+ 
   m_initialised = true;
 }
 
-void TextureManager::initGL()
-{
+void TextureManager::contextCreated() {
   assert((m_initialised == true) && "TextureManager not initialised");
   assert(m_initGL == false);
   
@@ -185,6 +195,12 @@ void TextureManager::initGL()
   m_default_font = createDefaultFont();
   if (m_default_font == -1) std::cerr << "Error building default font" << std::endl;
 
+  createCursor("cursor_default", arrow);
+  createCursor("cursor_pickup", pickup);
+  createCursor("cursor_touch", touch);
+  createCursor("cursor_use", use);
+  createCursor("cursor_attack", attack);
+
   m_initGL = true;
 }
 
@@ -198,6 +214,12 @@ void TextureManager::shutdown()
     unloadTexture(m_textures[i]);
   }
 
+  // Clean up sprites
+  while (!m_sprites.empty()) {
+   delete m_sprites.begin()->second;
+    m_sprites.erase(m_sprites.begin());
+  }
+
   m_last_textures.clear();
   m_initialised = false;
 }
@@ -210,7 +232,6 @@ void TextureManager::readTextureConfig(const std::string &filename) {
 
 GLuint TextureManager::loadTexture(const std::string &texture_name) {
   assert((m_initialised == true) && "TextureManager not initialised");
-  std::cout << "Loading Texture: " << texture_name << std::endl;
   std::string clean_name = std::string(texture_name);
   
   bool mask = false;
@@ -267,13 +288,15 @@ GLuint TextureManager::loadTexture(const std::string &name, SDL_Surface *surface
         ((unsigned char *)surface->pixels)[i + 2] = (unsigned char)0xff;
       }
     } else {
-      for (int i = 0; i < surface->w * surface->h * 3; i += 3) {
-        ((unsigned char *)surface->pixels)[i + 0] = (unsigned char)0xff;
-        ((unsigned char *)surface->pixels)[i + 1] = (unsigned char)0xff;
-        ((unsigned char *)surface->pixels)[i + 2] = (unsigned char)0xff;
+      for (int i = 0; i < surface->w * surface->h * surface->format->BytesPerPixel; i += surface->format->BytesPerPixel) {
+        for (int j = 0; j < surface->format->BytesPerPixel; ++j) {
+          ((unsigned char *)surface->pixels)[i + j] = (unsigned char)0xff;
+        }
       }
     }
   }
+
+
 // */ 
   // Create open gl texture
   GLuint texture_id;
@@ -354,7 +377,11 @@ GLuint TextureManager::loadTexture(const std::string &name, SDL_Surface *surface
 #else // SDL_BYTEORDER == SDL_LIL_ENDIAN
     if (surface->format->Rshift < surface->format->Bshift) {
 #endif // SDL_BYTEORDER == SDL_LIL_ENDIAN
+      if (sage_ext[GL_EXT_bgra]) {
         format = (bpp == 24) ? GL_BGR_EXT : GL_BGRA_EXT;
+      } else {
+        fprintf(stderr, "Unsupported sprite format bgr. No GL_EXT_bgra extension\n");
+      }
     } else {
         format = (bpp == 24) ? GL_RGB : GL_RGBA;
     }
@@ -373,7 +400,23 @@ GLuint TextureManager::loadTexture(const std::string &name, SDL_Surface *surface
             fmt = GL_RGB5_A1; break; // Set default
         }
     }
-  
+// TODO Create this in a new SDL_surface, and assign in surface so the mipmap stuff will work below 
+  int width = scaleDimension(surface->w);
+  int height = scaleDimension(surface->h);
+
+  // Scale the image to a 2^N x 2^M size that is within the size allowed by GL
+  bool free_surface = false;
+  if  (width != surface->w || height != surface->h) {
+
+    SDL_Surface *newSurface = SDL_CreateRGBSurface(SDL_SWSURFACE, width, height, surface->format->BitsPerPixel, surface->format->Rmask, surface->format->Gmask, surface->format->Bmask, surface->format->Amask);
+
+    gluScaleImage(format, surface->w, surface->h, GL_UNSIGNED_BYTE, surface->pixels, newSurface->w, newSurface->h, GL_UNSIGNED_BYTE, newSurface->pixels);
+
+//    SDL_FreeSurface(surface);
+    surface = newSurface;
+    free_surface = true;
+  }
+
   if (mipmap) {
     if (m_baseMipmapLevel == 0)
         glTexImage2D(GL_TEXTURE_2D, 0, fmt, surface->w, surface->h, 0, format, GL_UNSIGNED_BYTE, surface->pixels);
@@ -413,6 +456,7 @@ GLuint TextureManager::loadTexture(const std::string &name, SDL_Surface *surface
     // don't leak the final mipmap
     if (mip != surface) SDL_FreeSurface(mip);
   } else {
+    //glTexImage2D(GL_TEXTURE_2D, 0, fmt, surface->w, surface->h, 0, format, GL_UNSIGNED_BYTE, surface->pixels);
     glTexImage2D(GL_TEXTURE_2D, 0, fmt, surface->w, surface->h, 0, format, GL_UNSIGNED_BYTE, surface->pixels);
   }
 
@@ -422,6 +466,7 @@ GLuint TextureManager::loadTexture(const std::string &name, SDL_Surface *surface
     glPrioritizeTextures(1, &texture_id, &priority);
   }
   
+  if (free_surface) SDL_FreeSurface(surface);
   return texture_id;
 }
 
@@ -490,8 +535,10 @@ void TextureManager::generalConfigChanged(const std::string &section, const std:
         std::cout << "set base mipmap level to " << m_baseMipmapLevel << std::endl;
         
         // restart stuff as necessary
-        if (m_initGL)
-            invalidate();
+        if (m_initGL) {
+            contextDestroyed(true);
+            contextCreated();
+        }
     }
 }
 
@@ -527,7 +574,7 @@ void TextureManager::setupGLExtensions()
   if (debug && use_sgis_generate_mipmap) std::cout << "Using GL_SGIS_GENERATE_MIPMAP" << std::endl;
   
   use_ext_texture_filter_anisotropic = sage_ext[GL_EXT_TEXTURE_FILTER_ANISOTROPIC];
-  use_arb_texture_border_clamp = true;//sage_ext[GL_ARB_TEXTURE_BORDER_CLAMP];
+  use_arb_texture_border_clamp = sage_ext[GL_ARB_TEXTURE_BORDER_CLAMP];
 
 }
 
@@ -592,45 +639,9 @@ TextureID TextureManager::createDefaultTexture() {
 TextureID TextureManager::createDefaultFont() {
   assert((m_initialised == true) && "TextureManager not initialised");
   std::string texture_name = "default_font";
-/*
-  m_texture_config.setItem(texture_name, KEY_mask, false);
-  m_texture_config.setItem(texture_name, KEY_min_filter, FILTER_LINEAR);
-  m_texture_config.setItem(texture_name, KEY_mag_filter, FILTER_LINEAR);
-  m_texture_config.setItem(texture_name, KEY_clamp, true);
-  m_texture_config.setItem(texture_name, KEY_mipmap, false);
- 
-  // Load texture into memory
-  SDL_Surface *surface = IMG_ReadXPMFromArray(default_font_xpm);
-  if (!surface) {
-    std::cerr << "Error loading default font" << std::endl;
-    return -1;
-  }
-  TextureObject texture = loadTexture(texture_name, surface);
-  // Free image
-  SDL_FreeSurface(surface);
-
-*/
 
   GLuint texture;
-#if 0
 
-  unsigned int width, height;
-
-  unsigned char *data = xpm_to_image((const char**)default_font_xpm, width, height);
-  glGenTextures(1, &texture);
-
-  glBindTexture(GL_TEXTURE_2D, texture);
-  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER,GL_LINEAR);
-  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
-  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
-  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
-
-  glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, width, height, 0, GL_RGBA, GL_UNSIGNED_BYTE, data);
-  GLfloat priority = 1.0f;
-  glPrioritizeTextures(1, &texture, &priority);
-  
-  delete [] data;
-#else
   glGenTextures(1, &texture);
   glBindTexture(GL_TEXTURE_2D, texture);
   glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
@@ -646,10 +657,37 @@ TextureID TextureManager::createDefaultFont() {
   GLfloat priority = 1.0f;
   glPrioritizeTextures(1, &texture, &priority);
 
-#endif
+  TextureID texId = requestTextureID(texture_name, false);
+  m_textures[texId] = texture;
+  return texId;
+}
+
+TextureID TextureManager::createCursor(const std::string &texture_name, const char **xpm) {
+  assert((m_initialised == true) && "TextureManager not initialised");
+  unsigned int width, height;
+  GLuint texture;
+
+  glGenTextures(1, &texture);
+  glBindTexture(GL_TEXTURE_2D, texture);
+  unsigned char *data = xpm_to_image((const char**)xpm, width, height);
+
+  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
+  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
+  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
+  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
+
+  glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, width, height, 0, GL_RGBA, GL_UNSIGNED_BYTE, data);
+  delete [] data;
+
+  if (glGetError() != 0) {
+      std::cerr << "Failed to cursor touch texture" << std::endl << std::flush;
+  }
+  GLfloat priority = 1.0f;
+  glPrioritizeTextures(1, &texture, &priority);
 
   TextureID texId = requestTextureID(texture_name, false);
   m_textures[texId] = texture;
+
   return texId;
 }
 
@@ -690,36 +728,24 @@ void TextureManager::runCommand(const std::string &command, const std::string &a
 
 }
 
-void TextureManager::invalidate()
+void TextureManager::contextDestroyed(bool check)
 {
   assert((m_initialised == true) && "TextureManager not initialised");
   assert(m_initGL);
   
-  // TODO unload textures first.
-  for (unsigned int i = 0; i < m_textures.size(); i++) {
+  // unload textures first.
+  for (unsigned int i = 0; i < m_textures.size(); ++i) {
     // Unload texture if its still valid
-    if (glIsTexture(m_textures[i])) {
+    if (check  && glIsTexture(m_textures[i])) {
       glDeleteTextures(1, &m_textures[i]);
     }
     m_textures[i] = 0;
   }
 
   for (SpriteInstanceMap::iterator S=m_sprites.begin(); S != m_sprites.end(); ++S) {
-    S->second->invalidate();
+    S->second->contextDestroyed(check);
   }
-
-  // Determine available OpenGL extensions
-  setupGLExtensions();
-  
-  // Initialise our current texture cache
-  for (unsigned int i = 0; i < m_last_textures.size(); m_last_textures[i++] = -1);
-  // Setup default texture properties
-  m_default_texture = createDefaultTexture();
-  if (m_default_texture == -1) std::cerr << "Error building default texture" << std::endl;
-
-  // create default font
-  m_default_font = createDefaultFont();
-  if (m_default_font == -1) std::cerr << "Error building default font" << std::endl;
+  m_initGL = false;
 }
 
 GLint TextureManager::getFormat(const std::string &fmt) {
@@ -789,4 +815,9 @@ void TextureManager::clearLastTexture(unsigned int index)
     m_last_textures[index] = -1;
 }
 
+void TextureManager::varconf_error_callback(const char *error) {
+  printf("Varconf Error: %s\n ", error);
+}
+
+
 } /* namespace Sear */
