@@ -1,8 +1,8 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2004 Simon Goodall, University of Southampton
+// Copyright (C) 2001 - 2006 Simon Goodall, University of Southampton
 
-// $Id: TextureManager.h,v 1.17 2004/05/30 18:52:04 jmt Exp $
+// $Id: TextureManager.h,v 1.22 2006/01/28 15:35:49 simon Exp $
 
 #ifndef SEAR_RENDER_TEXTUREMANAGER_H
 #define SEAR_RENDER_TEXTUREMANAGER_H 1
@@ -64,8 +64,7 @@ public:
    * Destructor
    */ 
   ~TextureManager() {
-    // Call shutdown if it hasn't already been
-    if (m_initialised) shutdown();
+    assert (m_initialised == false);
   }
 
   /**
@@ -73,8 +72,6 @@ public:
    */ 
   void init();
 
-  void initGL();
-
   /**
    * Clean up the TextureManager object
    */ 
@@ -89,14 +86,20 @@ public:
   TextureID requestTextureID(const std::string &texture_name, bool mask)
   {
     assert(m_initialised);
+    // Convert to internal name
     std::string name = (mask) ? ("mask_" + texture_name) : (texture_name);
-    TextureID texId = m_texture_map[name];
-    
-    if (texId == 0) {
-        texId = m_names.size(); // we already made m_texture_map bigger
-        m_texture_map[name] = texId;
-        m_names.push_back(name);
-        m_textures.push_back(0);
+    // Find existing ID if any
+    TextureMap::const_iterator I = m_texture_map.find(name);
+    TextureID texId; 
+    if (I == m_texture_map.end()) {
+      // Assign new texture ID
+      texId = m_names.size();
+      m_texture_map[name] = texId;
+      m_names.push_back(name);
+      m_textures.push_back(0);
+    } else {
+      // Return existing id
+      texId = I->second;
     }
     
     return texId;
@@ -152,7 +155,8 @@ public:
   void runCommand(const std::string &command, const std::string &arguments);
   void setupGLExtensions();
  
-  void invalidate();
+  void contextCreated();
+  void contextDestroyed(bool check);
 
   static GLint getFormat(const std::string &fmt);
  
@@ -187,6 +191,7 @@ private:
 
   TextureID createDefaultTexture();
   TextureID createDefaultFont();
+  TextureID createCursor(const std::string &texture_name, const char **xpm);
   
   /**
    * Returns the OpenGL filter from the name
@@ -194,6 +199,8 @@ private:
    * @return The filter, or 0 is a wrong name was specified
    */ 
   static int getFilter(const std::string &filter_name);
+
+void varconf_error_callback(const char *error);
     
     typedef std::map<std::string, SpriteData*> SpriteInstanceMap;
     SpriteInstanceMap m_sprites;
