@@ -1,8 +1,8 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2002 Simon Goodall
+// Copyright (C) 2001 - 2005 Simon Goodall
 
-// $Id: ActionHandler.h,v 1.5 2003/03/23 19:51:49 simon Exp $
+// $Id: ActionHandler.h,v 1.9 2005/09/19 20:34:21 alriddoch Exp $
 
 #ifndef SEAR_ACTIONHANDLER_H
 #define SEAR_ACTIONHANDLER_H 1
@@ -41,23 +41,24 @@ public:
 
   void registerCommands(Console *console);
   void runCommand(const std::string &command, const std::string &args);
-
+  void addHandler(const std::string &action, const std::string &command);
 private:
   void varconf_callback(const std::string &section, const std::string &key, varconf::Config &config);
   void varconf_error_callback(const char *message);
   
-  
   typedef struct {
     std::string action;
     std::string script;
+    std::string command;
     bool entity_based;
   } ActionStruct;
-  
-  std::map<std::string, ActionStruct*> action_map;
+ 
+  typedef std::multimap<std::string, ActionStruct*> ActionMap; 
+  ActionMap action_map;
 
-  System *_system;
+  System *m_system;
 
-  bool _initialised;
+  bool m_initialised;
   
 };
   
