@@ -1,8 +1,8 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2004 Simon Goodall
+// Copyright (C) 2001 - 2005 Simon Goodall
 
-// $Id: FileHandler.cpp,v 1.13 2004/07/19 11:22:14 simon Exp $
+// $Id: FileHandler.cpp,v 1.18 2005/11/29 21:01:52 simon Exp $
 
 #ifdef HAVE_CONFIG_H
   #include "config.h"
@@ -16,6 +16,8 @@
 #include "FileHandler.h"
 #include "Console.h"
 
+#include "prefix.h"
+
 #ifdef __WIN32__
     #include <io.h> // for _access, Win32 version of stat()
     #include <direct.h> // for _mkdir
@@ -94,17 +96,13 @@ FileHandler::FileHandler() {
     addSearchPath(installBase + "/scripts");
     
     setVariable("SEAR_INSTALL", installBase);
-    setVariable("SEAR_MEDIA", installBase + "/sear-media/");
-    setVariable("DEFAULT_SEAR_MEDIA", installBase + "/sear-media/");
+    setVariable("SEAR_MEDIA", "${SEAR_INSTALL}/sear-media-0.6/");
+    setVariable("DEFAULT_SEAR_MEDIA", "${SEAR_INSTALL}/sear-media-0.6/");
     setVariable("SEAR_HOME", getUserDataPath());
     
     if (!exists(getUserDataPath())) {
-        std::cout << "creating user data directory at " << getUserDataPath() << std::endl;
-#ifdef __WIN32__
-        _mkdir(getUserDataPath().c_str()); 
-#else
-        mkdir(getUserDataPath().c_str(), 0755);
-#endif
+      std::cout << "creating user data directory at " << getUserDataPath() << std::endl;
+      mkdir(getUserDataPath());
     }
 }
 
@@ -113,11 +111,15 @@ FileHandler::~FileHandler() {}
 std::string FileHandler::getInstallBasePath() const
 {
 #ifdef __APPLE__
-    return getBundleResourceDirPath();
+  return getBundleResourceDirPath();
 #elif __WIN32__
-    return std::string(".");
+  return std::string(".");
 #else
-    return std::string(INSTALLDIR) + std::string("/share/sear");
+  #ifdef ENABLE_BINRELOC
+  return std::string(DATADIR) + std::string("/sear");
+#else
+  return std::string(INSTALLDIR) + std::string("/share/sear");
+#endif
 #endif
 }
 
@@ -196,17 +198,22 @@ void FileHandler::runCommand(const std::string &command, const std::string &args
 }
 
 void FileHandler::expandString(std::string &str) {
-  for (VarMap::const_iterator I = varMap.begin(); I != varMap.end(); ++I) {
-    std::string var = I->first;
-    std::string value = I->second;
-    var = "${" + var + "}";
-    for (std::string::size_type p=str.find(var); p != str.npos; p=str.find(var, p))
-   {
-      str.replace(p, var.length(), value);
-      p += value.length();
-   }
-
-//    replace(str.begin(), str.end(), "${" + var + "}", value);
+  bool changed = true;
+  while (changed) {
+    changed = false;
+    for (VarMap::const_iterator I = varMap.begin(); I != varMap.end(); ++I) {
+      std::string var = I->first;
+      std::string value = I->second;
+      var = "${" + var + "}";
+      for (std::string::size_type p=str.find(var); p != str.npos; p=str.find(var, p))
+     {
+        str.replace(p, var.length(), value);
+        p += value.length();
+        changed = true;
+     }
+  
+  //    replace(str.begin(), str.end(), "${" + var + "}", value);
+    }
   }
 }
 
@@ -231,4 +238,15 @@ bool FileHandler::exists(const std::string& file) const
 #endif
 }
 
+bool FileHandler::mkdir(const std::string &dirname) const {
+int err = 0;
+#ifdef __WIN32__
+       err =  _mkdir(dirname.c_str()); 
+#else
+       err =  ::mkdir(dirname.c_str(), 0755);
+#endif
+  return (err == 0);
+
+}
+
 } /* namespace Sear */
