@@ -1,8 +1,8 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2002 Simon Goodall
+// Copyright (C) 2001 - 2005 Simon Goodall
 
-// $Id: ScriptEngine.h,v 1.3 2003/03/23 19:51:49 simon Exp $
+// $Id: ScriptEngine.h,v 1.4 2005/12/06 20:59:06 simon Exp $
 
 #ifndef SEAR_SCRIPTENGINE_H
 #define SEAR_SCRIPTENGINE_H 1
@@ -27,17 +27,13 @@ public:
   void registerCommands(Console *console);
   void runCommand(const std::string &command, const std::string &args);
 
-  std::string getFileDirectory() const { return _file_dir; }
-  bool prefixEnabled() const { return _prefix_enabled; }
+  std::string getFileDirectory() const { return m_file_dir; }
+//  bool prefixEnabled() const { return _prefix_enabled; }
   
   
 private:  
-   bool _initialised;
-
-  bool _prefix_enabled;
-  std::string _file_dir;
-  
-  
+  bool m_initialised;
+  std::string m_file_dir;
 };
 
 } /* namespace Sear */
