@@ -1,19 +1,14 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2004 Simon Goodall, University of Southampton
-#ifdef HAVE_CONFIG_H
-  #include "config.h"
-#endif
-
+// Copyright (C) 2001 - 2006 Simon Goodall, University of Southampton
 
 #include "Sound.h"
-#include "Exception.h"
 #include "Console.h"
 #include "common/Log.h"
 #include <SDL/SDL.h>
 #include <unistd.h>
 
-// $Id: Sound.cpp,v 1.15 2004/05/23 13:32:29 jmt Exp $
+// $Id: Sound.cpp,v 1.18 2006/01/28 15:35:48 simon Exp $
 
 // TODO: The sound systems appear to have a large number of memory leaks in SDL and/or SDL_mixer
 
@@ -45,17 +40,18 @@ Sound::~Sound() {
   if (_initialised) shutdown();
 }
 	
-void Sound::init() {
+int Sound::init() {
   if (_initialised) shutdown();
   if (SDL_InitSubSystem(SDL_INIT_AUDIO) != 0) {
     Log::writeLog(std::string("Error init SDL_AUDIO: ") + SDL_GetError(), Log::LOG_ERROR);
-    throw Exception("Error initialising SDL Sound Subsystem!");
+    return 1;
   }
   if (Mix_OpenAudio(MIX_DEFAULT_FREQUENCY, MIX_DEFAULT_FORMAT, 2, 4096) != 0) {
     Log::writeLog(std::string("Error init SDL_mixer: ") + Mix_GetError(), Log::LOG_ERROR);
-    throw Exception("Error initialising SDL_mixer!");
+    return 1;
   }
   _initialised = true;
+  return 0;
 }
 
 void Sound::shutdown() {
