@@ -1,8 +1,8 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2004 Simon Goodall, University of Southampton
+// Copyright (C) 2001 - 2006 Simon Goodall, University of Southampton
 
-// $Id: System.h,v 1.49 2004/06/24 14:58:35 jmt Exp $
+// $Id: System.h,v 1.67 2006/01/29 18:33:56 alriddoch Exp $
 
 #ifndef SEAR_SYSTEM_H
 #define SEAR_SYSTEM_H 1
@@ -15,25 +15,21 @@
 
 #include "interfaces/ConsoleObject.h"
 #include <varconf/Config.h>
+#include <wfmath/point.h>
 
 namespace Sear {
 	
 // Forward declarations
 class ActionHandler;
-class Render;
 class Calendar;
 class Client;
-class EventHandler;
 class FileHandler;
-class ModelHandler;
-class ObjectHandler;
 class ScriptEngine;
-//class StateLoader;
 class Console;
-class Workspace;
+class Workarea;
 class Character;
-class Graphics;
 class Sound;
+class Editor;
 
 typedef enum {
   SYS_UNKNOWN = 0,
@@ -47,6 +43,8 @@ typedef enum {
 #define ACTION_DEFAULT (0)
 #define ACTION_PICKUP (1)
 #define ACTION_TOUCH (2)
+#define ACTION_USE (3)
+#define ACTION_ATTACK (4)
 
 /**
  * This class is the root object for Sear. All the higher level classes will be created by
@@ -90,11 +88,23 @@ public:
    */
   void setCaption(const std::string &title, const std::string &icon); 
 
+  /**
+   * Sets the Window size
+   * @param w Window width
+   * @param h Window height
+   */
+  void resizeScreen(int w, int h);
+
   /**
    * This toggles the mlook flag
    */
   void toggleMouselook();
 
+  /**
+   * Return if mouselook is currently set
+   */
+  bool isMouselookEnabled() const;
+
   /**
    * This passes a command string to the console to run. The first word encountered
    * will be sent as the command, the remainder will be sent as args.
@@ -132,59 +142,49 @@ public:
   float getTimef() const { return (float)SDL_GetTicks() / 1000.0f; }
   double getTimeD() const { return (double)SDL_GetTicks() / 1000.0; }
 
-  void updateTime(double time);
+  /**
+   * Gets the time in seconds from the last frame start to the current
+   * frame start.
+   * @return Elapsed time in seconds
+   */
+  double getTimeElapsed() const { return m_elapsed; }
 
   /**
    * Set a system state
    * @param ss Sytem state to set
    * @param state Value of state
    */ 
-  void setState(SystemState ss, bool state) { _systemState[ss] = state; }
+  void setState(SystemState ss, bool state);// { m_systemState[ss] = state; }
   
   /**
    * Get value of a system state
    * @param ss System state to query
    * @return Value of query state
    */ 
-  bool checkState(SystemState ss) { return _systemState[ss]; }
+  bool checkState(SystemState ss) const { return m_systemState[ss]; }
 
-  Graphics *getGraphics() const { return _graphics; }
-  
   /**
    * Get the General Config object
    * @return Reference to general config object
    */ 
   varconf::Config &getGeneral() { return m_general; }
+  
   /**
-   * Get the Model Config object
-   * @return Reference to model config object
-   */ 
-  varconf::Config &getModel() { return _models; } 
-  /**
-   * Get the ModelRecords Config object
-   * @return Reference to ModelRecords config object
-   */ 
-  varconf::Config &getModelRecords() { return _model_records; }
-  /**
-   * Get the ObjectRecords Config object
-   * @return Reference to ObjectRecords config object
-   */ 
-  varconf::Config &getObjectRecords() { return _object_records; }
+   * Enable or disable key repeating.
+   * @param bEnable The state of the key repeating.
+   **/
+  void vEnableKeyRepeat(bool bEnable = true);
  
-  ScriptEngine *getScriptEngine() const { return _script_engine; }
-  EventHandler *getEventHandler() const { return _event_handler; }
-  ModelHandler *getModelHandler() const { return _model_handler; }
-  ActionHandler *getActionHandler() const { return _action_handler; }
-  FileHandler *getFileHandler() const { return _file_handler; }
-  ObjectHandler *getObjectHandler() const { return _object_handler; }
-  Calendar *getCalendar() const { return _calendar; }
+  ScriptEngine *getScriptEngine() const { return m_script_engine; }
+  ActionHandler *getActionHandler() const { return m_action_handler; }
+  FileHandler *getFileHandler() const { return m_file_handler; }
+  Calendar *getCalendar() const { return m_calendar; }
   
-  Console *getConsole() { return _console; }
-  Workspace *getWorkspace() { return _workspace; }
-  Character *getCharacter() { return _character; }
-  void setCharacter(Character *);
+  Console *getConsole() const { return m_console; }
+  Workarea *getWorkarea() const { return m_workarea; }
+  Character *getCharacter() const { return m_character; }
   
-  static System *instance() { return _instance; }
+  static System *instance() { return m_instance; }
 
   void switchCursor(int);
   void setAction(int);
@@ -193,66 +193,55 @@ public:
 
   void registerCommands(Console *);
   void runCommand(const std::string &command, const std::string &args);
-  Client *getClient() { return _client; }
+  Client *getClient() const { return m_client; }
+
+  int getWidth() const { return m_width; }
+  int getHeight() const { return m_height; }
 protected:
-  bool repeat; 
-  int action;
   bool initVideo();
   
   void handleEvents(const SDL_Event &);
   void handleAnalogueControllers();
-  void handleJoystickMotion(Uint8 axis, Sint16 value);
-  
-  bool mouseLook;
-  SDL_Surface *screen;
-  Graphics *_graphics;
-  Render *renderer;
-  Client *_client;
-  static System *_instance;
-  std::string m_command;
-  std::string _icon_file;
-  SDL_Surface *_icon;
+  void handleJoystickMotion(Uint8 axis, Sint16 value);  
+  void processRecords();
+
+  int m_action;
+  bool m_mouseLook;
+  SDL_Surface *m_screen;
+  Client *m_client;
+  static System *m_instance;
   
   int m_width;
   int m_height;
+  int m_KeyRepeatDelay;
+  int m_KeyRepeatRate;
 
-  bool _click_on;
-  int _click_x;
-  int _click_y;
-  std::string _click_id;
-  double _click_seconds;
+  bool m_click_on;
+  int m_click_x;
+  int m_click_y;
+  std::string m_click_id;
+  double m_click_seconds;
+  WFMath::Point<3> m_click_pos;
 
-  ScriptEngine *_script_engine; ///< Pointer to scripting engine object
-  EventHandler *_event_handler; ///< Pointer to event handler object
-  FileHandler *_file_handler; ///< Pointer to file handler object
-  ModelHandler *_model_handler; ///< Pointer to model handler object
-  ActionHandler *_action_handler; ///< Pointer to action handler object
-  ObjectHandler *_object_handler; ///< Pointer to object handler object
-  Calendar *_calendar; ///< Pointer to calender object
+  ScriptEngine *m_script_engine; ///< Pointer to scripting engine object
+  FileHandler *m_file_handler; ///< Pointer to file handler object
+  ActionHandler *m_action_handler; ///< Pointer to action handler object
+  Calendar *m_calendar; ///< Pointer to calender object
    
   varconf::Config m_general;
-  varconf::Config _models;
 
-  varconf::Config _model_records;
-  varconf::Config _object_records;
-  
-  SDL_Joystick *_controller;
-  Console *_console;
-  Workspace *_workspace;
-  Character *_character;
+  SDL_Joystick *m_controller;
+  Console *m_console;
+  Workarea *m_workarea;
+  Character *m_character;
  
-  static SDL_Cursor *buildCursor(const char *image[]);
-
-  void readConfig();
-  void writeConfig();
-  std::string install_path;  
-  SDL_Cursor *_cursor_default;
-  SDL_Cursor *_cursor_pickup;
-  SDL_Cursor *_cursor_touch;
+  void readConfig(varconf::Config &config);
+  void writeConfig(varconf::Config &config);
 
   bool m_mouse_move_select;
 
-  double _seconds;
+  double m_seconds;
+  double m_elapsed;
 
   typedef struct {
     std::string section;
@@ -260,10 +249,9 @@ protected:
     varconf::Config *config;
   } VarconfRecord;
 
-  std::list<VarconfRecord*> record_list;
-  bool _process_records;
-  void processRecords();
-  Sound *sound;
+  std::list<VarconfRecord*> m_record_list;
+  bool m_process_records;
+  Sound *m_sound;
   
   typedef enum {
     AXIS_STRAFE,
@@ -280,14 +268,17 @@ public:
   void varconf_general_callback(const std::string &, const std::string &, varconf::Config &);
   void varconf_error_callback(const char *);
   
+  SigC::Signal3<void, std::string, int, int> pushedMessage;
+
+  sigc::signal<void> EnteredWorld;
+  sigc::signal<void> LeftWorld;
 private:
-  bool _systemState[SYS_LAST_STATE]; ///< Array storing various system states
-  bool _system_running; ///< Flag determining when mainLoop terminates (setting to false terminates)
+  bool m_systemState[SYS_LAST_STATE]; ///< Array storing various system states
+  bool m_system_running; ///< Flag determining when mainLoop terminates (setting to false terminates)
 
-  std::list<std::string> _command_history;
-  std::list<std::string>::iterator _command_history_iterator;
-
-  bool _initialised; ///< Initialisation state of System
+  Editor *m_editor;
+  bool m_initialised; ///< Initialisation state of System
+  bool m_startFullscreen;
 };
 
 } /* namespace Sear */
