@@ -2,7 +2,7 @@
 // the GNU General Public License (See COPYING for details).
 // Copyright (C) 2001 - 2002 Simon Goodall, University of Southampton
 
-// $Id: client.h,v 1.17 2004/06/13 18:21:01 simon Exp $
+// $Id: client.h,v 1.23 2005/12/15 00:17:14 alriddoch Exp $
 
 #ifndef SEAR_CLIENT_H
 #define SEAR_CLIENT_H 1
@@ -11,12 +11,16 @@
 
 #include <Eris/Connection.h>
 #include <Eris/Log.h>
-#include <Eris/Player.h>
+#include <Eris/Account.h>
 #include <Atlas/Message/DecoderBase.h>
-
-#include "conf.h"
 #include "interfaces/ConsoleObject.h"
 
+#include <sigc++/object.h>
+
+namespace varconf {
+class Config;
+}
+
 //Client Messages
 #define CLIENT_CONNECTING       "Connecting"
 #define CLIENT_CONNECTED        "Connected"
@@ -39,29 +43,31 @@
 #define CLIENT_NETWORK_FAILURE "Network Failure"
 #define CLIENT_ERIS_LOG_HEAD   "Eris Log:"
 
-#define CLIENT_STATUS_DISCONNECTED (0)
-#define CLIENT_STATUS_CONNECTED    (1)
-#define CLIENT_STATUS_LOGGED_IN    (2)
-#define CLIENT_STATUS_IN_WORLD     (3)
+typedef enum {
+  CLIENT_STATUS_DISCONNECTED = 0,
+  CLIENT_STATUS_CONNECTING,
+  CLIENT_STATUS_DISCONNECTING,
+  CLIENT_STATUS_CONNECTED,
+  CLIENT_STATUS_LOGGING_IN,
+  CLIENT_STATUS_LOGGING_OUT,
+  CLIENT_STATUS_LOGGED_IN,
+  CLIENT_STATUS_GOING_IN_WORLD,
+  CLIENT_STATUS_GOING_OUT_WORLD,
+  CLIENT_STATUS_IN_WORLD,
+  CLIENT_STATUS_LAST
+} ClientStatus;
 
 namespace Eris {
-  class Meta;
-  class Player;
+  class Account;
   class Connection;
-  class Lobby;
-  class Person;
-  class World;
-  class ServerInfo;
 }
 
 namespace Sear {
 class Factory;
-class WorldEntity;
 class Console;
-class Lobby;
 class System;
 
-class Client :public SigC::Object, public ConsoleObject {
+class Client : public SigC::Object, public ConsoleObject {
 
 public:
   Client(System *system, const std::string &client_name);
@@ -70,8 +76,7 @@ public:
   bool init();
   void shutdown();
   
-  int connect(const std::string &, int port = DEFAULT_PORT);
-  int reconnect();
+  int connect(const std::string &, int port = 6767);
   int disconnect();
 
   int createAccount(const std::string &, const std::string &, const std::string &);
@@ -85,16 +90,19 @@ public:
   void poll();
   std::string getStatus();
   
-  int listRooms();
-
   void registerCommands(Console *);
   void runCommand(const std::string &command, const std::string &args);
-  void getServers();
-  void stopServers();
  
-  Eris::Player *getPlayer() { return _player; }
+  Eris::Account    *getAccount() const { return m_account; }
+  Eris::Avatar     *getAvatar() const { return m_avatar; }
+  Eris::Connection *getConnection() const { return m_connection;  }
+
+  void readConfig(varconf::Config &config);
+  void writeConfig(varconf::Config &config) const;
  
 protected:
+  void setStatus(int status);
+  void setErisLogLevel(const std::string &level);
   //Callbacks
 
   //Connection
@@ -102,50 +110,35 @@ protected:
   void NetConnected();
   void NetDisconnected();
   bool NetDisconnecting();
-  void Timeout(Eris::Connection::Status);
   void StatusChanged(Eris::Connection::Status);
   void Log(Eris::LogLevel, const std::string &);
-  void GotTime(double time);
 
-  //Lobby
-  void LoggedIn(const Atlas::Objects::Entity::Player &p);
-  void SightPerson(Eris::Person*);
-
-  //Player
+  // Account
   void LoginSuccess();
-  void LoginFailure(Eris::LoginFailureType, const std::string&);
+  void LoginFailure(const std::string&);
   void LogoutComplete(bool);
-  void GotCharacterInfo(const Atlas::Objects::Entity::GameEntity&);
+  void GotCharacterInfo(const Atlas::Objects::Entity::RootEntity&);
   void GotAllCharacters();
+  void AvatarSuccess(Eris::Avatar *);
+  void AvatarFailure(const std::string &msg);
 
-  //World	
-  void EntityCreate(Eris::Entity*);
-  void EntityDelete(Eris::Entity*);
-  void Entered(Eris::Entity*);
-  void Appearance(Eris::Entity*);
-  void Disappearance(Eris::Entity*);
-  void RootEntityChanged(Eris::Entity*);
 
-  //Metaserver
-  void gotServerCount(int count);
-  void gotFailure(const std::string& msg);
-  void receivedServerInfo(const Eris::ServerInfo & sInfo);
-  void completedServerList();
+  void GotCharacterEntity(Eris::Entity *e);
 
-  System *_system;
+  System *m_system;
 
-  Eris::Connection* _connection;
-  Eris::Player* _player;
-  Eris::Lobby* _lobby;
-  Lobby *the_lobby;
-  Eris::Meta *_meta;
+  Eris::Connection *m_connection;
+  Eris::Account    *m_account;
+  Eris::Avatar     *m_avatar;
 
-  Factory *_factory;
+  Factory *m_factory;
   
-  int _status;
-  std::string _client_name;
-  bool _initialised;
+  int m_status;
+  std::string m_client_name;
+  bool m_initialised;
   bool m_takeFirst;
+
+  Eris::LogLevel m_loglevel;
 };
 
 } /* namespace Sear */
