@@ -1,8 +1,9 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001 - 2004 Simon Goodall, University of Southampton
+// Copyright (C) 2001 - 2006 Simon Goodall, University of Southampton
+
+// $Id: main.cpp,v 1.30 2006/01/30 17:32:24 simon Exp $
 
-// $Id: main.cpp,v 1.20 2004/05/14 12:17:21 simon Exp $
 #ifdef HAVE_CONFIG_H
   #include "config.h"
 #endif
@@ -10,15 +11,10 @@
 #include <unistd.h>
 #include <iostream>
 #include <string>
-
-#ifdef HAVE_CONFIG_H
-    #include "config.h"
-#endif
-
-#include "conf.h"
 #include "System.h"
-#include "Exception.h"
+#include "error.h"
 
+#include <signal.h>
 
 #ifdef USE_MMGR
   #include "common/mmgr.h"
@@ -32,9 +28,15 @@
 #if defined(_WIN32)
 int SDL_main(int argc, char** argv) {
 #else
-
 int main(int argc, char** argv) {
 #endif
+
+#ifndef _WIN32 
+  if (signal(SIGPIPE, SIG_IGN) == SIG_ERR) {
+    fprintf(stderr, "Warning: Attempt to ignore SIGPIPE failed.\n");
+  }
+#endif
+
   bool exit_program = false;
   Sear::System *sys = NULL;
   std::list<std::string> path_list;
@@ -50,7 +52,7 @@ int main(int argc, char** argv) {
       argv++;
       argc--;
       if (arg == "-v" || arg == "--version") {
-        std::cout << "Sear version: " << VERSION << std::endl;
+      //  std::cout << "Sear version: " << VERSION << std::endl;
 	exit_program = true;
       }
       else if (arg == "-a" || arg == "--add-search-path") {
@@ -85,16 +87,16 @@ under certain conditions; type `show c' for details.
   
   sys = new Sear::System();
   sys->addSearchPaths(path_list);
+
   if (!sys->init(p_argc, p_argv)) {
     std::cerr << "Error initialising Sear!" << std::endl;
+    Sear::ErrorDialog("Error initialising Sear. See log files or stdout/stderr for more details");
     exit (1);
   }
   try {
   //  sys->createWindow(false);
-    sys->setCaption(CLIENT_NAME, CLIENT_NAME);
+    sys->setCaption("Sear", "Sear");
     sys->mainLoop();
-  } catch (Sear::Exception e) {
-    std::cerr << "Exception: " << e.getMessage() << std::endl;
   } catch (...) {
     std::cerr << "Unknown Exception" << std::endl;
   }
